@@ -70,17 +70,30 @@ bristolJackTest()
 int
 main(int argc, char *argv[])
 {
+	int outfd, nullfd;
+	char lbuf[80];
+
 #ifdef _BRISTOL_JACK /* _BRISTOL_JACK */
-	printf("%s connects to jack to find rate and counts\n", argv[0]);
+//	printf("%s: connect to jackd to find samplerate and period size\n",
+//		argv[0]);
+
+	/* I don't want all the output from jack, redirect it */
+	outfd = dup(STDOUT_FILENO);
+	nullfd = open("/dev/null", O_WRONLY);
+	dup2(nullfd, STDOUT_FILENO);
+	dup2(nullfd, STDERR_FILENO);
+
 	if (bristolJackTest() != 0)
 		return(-1);
 
-	printf("JACKSTATS: %i %i\n", samplerate, samplecount);
+	snprintf(lbuf, 80, "JACKSTATS: %i %i\n", samplerate, samplecount);
+
+	nullfd = write(outfd, lbuf, strlen(lbuf));
 
 	return(0);
 #else
 	printf("This should connect to jack but it does not appear to be compiled\n");
-	return(-1);
+	return(-2);
 #endif /* _BRISTOL_JACK */
 
 }
