@@ -98,31 +98,31 @@ static char *defname = "bristol";
 
 void *eventMgr();
 
-int readMe = 0;
-int gmc = 0;
-int opacity = 60;
-int gs = 1;
-int nar = 0;
-int azoom = 0;
-int quality = 6;
-int deswidth = -1;
-float scale = 1.0;
-float antialias = 0.0;
-int aliastype = 0;
-int library = 1;
-int dcTimeout = 500000;
-int sampleRate = 44100;
-int sampleCount = 256;
-int mwt = 50000;
-int activeSense = 2000;
-int activeSensePeriod = 15000;
-int bwflags = BRIGHTON_POST_WINDOW;
-int rlflags = BRIGHTON_SET_RAISE|BRIGHTON_SET_LOWER;
-int nrpcc = BRIGHTON_NRP_COUNT;
-int cli = 0;
-int cli_fd[2];
+static int readMe = 0;
+static int gmc = 0;
+static int opacity = 60;
+static int gs = 1;
+static int nar = 0;
+static int azoom = 0;
+static int quality = 6;
+static int deswidth = -1;
+static float scale = 1.0;
+static float antialias = 0.0;
+static int aliastype = 0;
+static int library = 1;
+static int dcTimeout = 500000;
+static int sampleRate = 44100;
+static int sampleCount = 256;
+static int mwt = 50000;
+static int activeSense = 2000;
+static int activeSensePeriod = 15000;
+static int bwflags = BRIGHTON_POST_WINDOW;
+static int rlflags = BRIGHTON_SET_RAISE|BRIGHTON_SET_LOWER;
+static int nrpcc = BRIGHTON_NRP_COUNT;
+static int cli = 0;
+static int cli_fd[2];
 
-static char *BRISTOL_DEF_HOST = "localhost";
+static char defaultcdev[16];
 
 extern int vuInterval;
 void printBrightonHelp(int);
@@ -159,6 +159,21 @@ loadhandler()
 		ladiRequest = 0;
 }
 
+static void
+printSummaryText()
+{
+	int i;
+
+	for (i = 0 ; i < BRISTOL_SYNTHCOUNT; i++)
+	{
+		if ((synthesisers[i] != NULL)
+			&& (synthesisers[i]->name != NULL)
+			&& (synthesisers[i]->name[0] != '\0'))
+			printf("%s ", synthesisers[i]->name);
+	}
+	printf("\n");
+}
+
 static void
 brightonFindEmulation(int argc, char **argv)
 {
@@ -174,6 +189,24 @@ brightonFindEmulation(int argc, char **argv)
 			if (synthesisers[i] == NULL)
 				continue;
 
+			/* Check for a few aliases */
+			if (strcmp("-2600", argv[argCount]) == 0)
+				found = global.synths->synthtype = BRISTOL_2600;
+			if (strcmp("-mg1", argv[argCount]) == 0)
+				found = global.synths->synthtype = BRISTOL_REALISTIC;
+			if (strcmp("-bme700", argv[argCount]) == 0)
+				found = global.synths->synthtype = BRISTOL_BME700;
+			if (strcmp("-pro10", argv[argCount]) == 0)
+				found = global.synths->synthtype = BRISTOL_PROPHET10;
+			if (strcmp("-pro52", argv[argCount]) == 0)
+				found = global.synths->synthtype = BRISTOL_PRO52;
+			if ((strcmp("-poly6", argv[argCount]) == 0)
+				|| (strcmp("-polysix", argv[argCount]) == 0))
+				found = global.synths->synthtype = BRISTOL_POLY6;
+			if ((strcmp("-memmoog", argv[argCount]) == 0)
+				|| (strcmp("-memorymoog", argv[argCount]) == 0))
+				found = global.synths->synthtype = BRISTOL_MEMMOOG;
+
 			if ((strcmp("-emulate", argv[argCount]) == 0)
 				&& (argCount < (argc - 1)))
 			{
@@ -195,11 +228,11 @@ brightonFindEmulation(int argc, char **argv)
 
 	if (found > 0)
 		printf("%s emulation defaults:\n", synthesisers[i]->name);
-	else
+	else {
 		printf("emulation defaults:\n");
+	}
 
-	if ((global.synths->voices = synthesisers[i]->emulate.voices)
-		< 0)
+	if ((global.synths->voices = synthesisers[i]->emulate.voices) < 0)
 	{
 		printf("    -voices  %i\n", BRISTOL_VOICECOUNT);
 		global.synths->voices = BRISTOL_VOICECOUNT;
@@ -274,9 +307,11 @@ main(int argc, char **argv)
 	global.synths->notepref = BRIGHTON_POLYPHONIC;
 	global.synths->notetrig = 0;
 	global.synths->win = NULL;
-	global.synths->flags = REQ_FORWARD|REQ_LOCAL_FORWARD|REQ_REMOTE_FORWARD;
+	global.synths->flags =
+		REQ_FORWARD|REQ_LOCAL_FORWARD|REQ_REMOTE_FORWARD|NO_LATCHING_KEYS;
 	global.port = 5028;
-	global.host = BRISTOL_DEF_HOST;
+	snprintf(defaultcdev, 16, "localhost");
+	global.host = defaultcdev;
 
 	memset(synthesisers, 0, sizeof(synthesisers));
 
@@ -352,9 +387,14 @@ main(int argc, char **argv)
 		exit(0);
 	}
 
+	if ((argc > 1) && (strcmp(argv[1], "--summary") == 0))
+	{
+		printSummaryText();
+		exit(0);
+	}
 	if ((argc > 1) && (strcmp(argv[1], "-summary") == 0))
 	{
-		printf("%s", summarytext);
+		printf("%s\n", summarytext);
 		exit(0);
 	}
 
@@ -850,6 +890,9 @@ main(int argc, char **argv)
 		}
 /* Need to add in PitchWheel Depth (done), Find and Coarse tuning*/
 
+		if (strcmp(argv[argCount], "-neutral") == 0)
+			global.synths->location = -1;
+
 		if ((strcmp(argv[argCount], "-load") == 0) && (argCount < argc))
 		{
 			if (argCount < argc)
@@ -917,9 +960,12 @@ main(int argc, char **argv)
 
 		if ((strcmp(argv[argCount], "-voices") == 0) && (argCount < argc))
 		{
-			if (((global.synths->voices = atoi(argv[argCount + 1])) == 1)
+			if ((atoi(argv[argCount + 1]) > 0)
+				&& ((global.synths->voices = atoi(argv[argCount + 1])) == 1)
 				&& (global.synths->notepref == BRIGHTON_POLYPHONIC))
 				global.synths->notepref = BRIGHTON_HNP;
+			else if (atoi(argv[argCount + 1]) == 0)
+				global.synths->voices = BRISTOL_VOICECOUNT;
 			argCount++;
 		}
 
@@ -999,6 +1045,8 @@ main(int argc, char **argv)
 			global.synths->flags |= NO_KEYTRACK;
 			argCount++;
 		}
+		if (strcmp(argv[argCount], "-keytoggle") == 0)
+			global.synths->flags &= ~NO_LATCHING_KEYS;
 
 		if (strcmp(argv[argCount], "-port") == 0)
 		{
@@ -1008,7 +1056,7 @@ main(int argc, char **argv)
 		}
 
 		if (strcmp(argv[argCount], "-host") == 0)
-			global.host = argv[++argCount];
+			snprintf(defaultcdev, 16, "%s", argv[++argCount]);
 
 		if (strcmp(argv[argCount], "-window") == 0)
 			synthesisers[global.synths->synthtype]->flags ^= BRIGHTON_WINDOW;
@@ -1095,6 +1143,7 @@ main(int argc, char **argv)
 		if (strcmp(argv[argCount], "-cs80") == 0)
 		{
 			global.synths->synthtype = BRISTOL_CS80;
+			printf("The CS80 is not an operational emulator\n");
 			global.libtest = 1;
 		}
 
@@ -1113,6 +1162,7 @@ main(int argc, char **argv)
 		if (strcmp(argv[argCount], "-sampler") == 0)
 		{
 			global.synths->synthtype = BRISTOL_SAMPLER;
+			printf("The sampler is not an operational emulator\n");
 			global.libtest = 1;
 		}
 
@@ -1133,6 +1183,7 @@ main(int argc, char **argv)
 		if (strcmp(argv[argCount], "-mixer") == 0)
 		{
 			global.libtest = 1;
+			printf("The bristol mixer is not an operational emulator\n");
 			global.synths->synthtype = BRISTOL_MIXER;
 		}
 
@@ -1198,6 +1249,7 @@ main(int argc, char **argv)
 		if (strcmp(argv[argCount], "-ms20") == 0)
 		{
 			global.synths->synthtype = BRISTOL_MS20;
+			printf("The ms20 is not an operational emulator\n");
 			global.libtest = 1;
 		}
 
@@ -1271,6 +1323,7 @@ main(int argc, char **argv)
 			|| (strcmp(argv[argCount], "-aks") == 0))
 		{
 			global.synths->synthtype = BRISTOL_SAKS;
+			printf("AKS is not an operational emulator\n");
 			global.libtest = 1;
 		}
 
@@ -1278,6 +1331,7 @@ main(int argc, char **argv)
 			|| (strcmp(argv[argCount], "-quantum") == 0))
 		{
 			global.synths->synthtype = BRISTOL_GRANULAR;
+			printf("The granular is not an operational emulator\n");
 			global.libtest = 1;
 		}
 
@@ -1402,6 +1456,14 @@ main(int argc, char **argv)
 		argCount++;
 	}
 
+	if (strncmp("unix:", defaultcdev, 5) == 0)
+	{
+		if (strlen(defaultcdev) == 5)
+			snprintf(defaultcdev, 16, "unix:%i", global.port);
+		else
+			global.port = atoi(&defaultcdev[5]);
+	}
+
 #ifndef BRIGHTON_HAS_X11
 	/* Reverse the window logic */
 	synthesisers[global.synths->synthtype]->flags ^= BRIGHTON_WINDOW;
