@@ -604,7 +604,7 @@ axxeInit(brightonWindow *win)
 	 * We need to take a copy here since the value may change as the synth
 	 * is drawn
 	 */
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
@@ -803,10 +803,11 @@ axxeConfigure(brightonWindow* win)
 	if (synth->flags & OPERATIONAL)
 		return(0);
 
-printf("going operational\n");
+	printf("going operational\n");
 
 	synth->bank = 10;
-	synth->location = 11;
+	if (synth->location == 0)
+		synth->location = 11;
 
 	synth->flags |= OPERATIONAL;
 	synth->keypanel = 1;
