@@ -1209,10 +1209,10 @@ BME700Configure(brightonWindow *win)
 		return(-1);
 	}
 
-	if (synth->location == 0) {
+	else if (synth->location == 0) {
 		synth->bank = 0;
 		synth->location = 1;
-	} else {
+	} else if (synth->location > 0) {
 		synth->bank = ((synth->location / 10) * 10) % 100;
 		if (((synth->location = synth->location % 10) == 0)
 			|| (synth->location > 8))
