@@ -439,7 +439,7 @@ brightonApp dxApp = {
 	dxMidiCallback,
 	destroySynth,
 	{8, 0, 2, 2, 5, 520, 0, 0},
-	820, 300,
+	820, 300, 0, 0,
 	15, /* one panel only */
 	{
 		{
