@@ -919,13 +919,13 @@ granularConfigure(brightonWindow *win)
 	if (synth->flags & OPERATIONAL)
 		return(0);
 
-printf("going operational\n");
+	printf("going operational\n");
 
 	synth->flags |= OPERATIONAL;
 	synth->keypanel = KEY_PANEL;
 	synth->keypanel2 = -1;
 	synth->transpose = 36;
-	loadMemory(synth, "granular", 0, 0, synth->mem.active, 0, 0);
+	loadMemory(synth, "granular", 0, synth->location, synth->mem.active, 0, 0);
 
 	/*
 	 * Hm. This is a hack for a few bits of bad rendering of a keyboard. Only
