@@ -329,7 +329,7 @@ brightonApp hammondApp = {
 	0,
 	destroySynth,
 	{32, 0, 2, 2, 5, 520, 0, 0},
-	808, 259,
+	808, 259, 0, 0,
 	5, /* four panels */
 	{
 		{
