@@ -33,6 +33,7 @@ static int hammondB3Callback(brightonWindow *, int, int, float);
 static int hammondB3destroy();
 /*static int keyCallback(void *, int, int, float); */
 /*static int modCallback(void *, int, int, float); */
+static void doClick();
 
 static int dc = 0, shade_id;
 
@@ -223,19 +224,19 @@ static brightonLocations locations[C_COUNT] = {
 	 * really make sense.
 	 */
 	{"", BRIGHTON_HAMMOND, Cm2, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", BRIGHTON_HAMMOND, Cm1, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", BRIGHTON_HAMMOND, Cm2, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", BRIGHTON_HAMMOND, Cm1, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", BRIGHTON_HAMMOND, Cm2, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", BRIGHTON_HAMMOND, Cm1, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", BRIGHTON_HAMMOND, Cm2, R1, W1, L1, 0, 8, 0,
-		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN},
+		"bitmaps/knobs/hammondbrown.xpm", 0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 };
 
 static brightonLocations volume[1] = {
@@ -432,21 +433,21 @@ static brightonLocations opts[OPTS_COUNT] = {
 		0, BRIGHTON_NOSHADOW},
 
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 	{"", 0, OC10, OR7, OS3, OS3, 0, 1, 0, "bitmaps/knobs/knobbluenew.xpm",
-		0, BRIGHTON_WITHDRAWN},
+		0, BRIGHTON_WITHDRAWN|BRIGHTON_NOSHADOW},
 };
 
 static int commonPreset = -1;
@@ -620,7 +621,7 @@ brightonApp hammondB3App = {
 	hammondB3Configure, /* 3 callbacks, unused? */
 	hammondB3MidiCallback,
 	hammondB3destroy,
-	{-1, 0, 2, 1, 5, 520, 0, 0},
+	{-1, 0, 2, 2, 5, 175, 0, 0},
 	765, 400, 0, 0,
 	15,
 	{
@@ -1169,6 +1170,7 @@ doVibra(guiSynth *synth, int fd, int chan, int cont, int op, int v)
 			bristolMidiSendMsg(global.controlfd, synth->sid, 6, 1, v);
 			break;
 		case 2:
+			doClick(synth);
 			if (v == 3) {
 				bristolMidiSendMsg(global.controlfd, synth->sid, 126, 0, 0);
 				return;
@@ -1267,11 +1269,19 @@ doDamping(guiSynth *synth, int fd, int chan, int cont, int op, int value)
 static void
 doClick(guiSynth *synth)
 {
-/*printf("doClick()\n"); */
+	float scale = 1.0;
+
+	if (synth->mem.param[DEVICE_START + 20] != 3)
+		scale = 0.1;
+
+	/*
+	 * If we have VC enabled then reduce the click volume by half, otherwise
+	 * it is full strength.
+	 */
 	b3SendMsg(global.controlfd, synth->sid, 0, 6,
-		(int) (synth->mem.param[OPTS_START + 23] * C_RANGE_MIN_1));
+		(int) (synth->mem.param[OPTS_START + 23] * C_RANGE_MIN_1 * scale));
 	b3SendMsg(global.controlfd, synth->sid2, 0, 6,
-		(int) (synth->mem.param[OPTS_START + 23] * C_RANGE_MIN_1));
+		(int) (synth->mem.param[OPTS_START + 23] * C_RANGE_MIN_1 * scale));
 }
 
 static void
