@@ -748,6 +748,32 @@ miniInit(brightonWindow *win)
 	return(0);
 }
 
+static void
+configureKeylatch(guiSynth *synth)
+{
+	if (synth->keypanel < 0)
+		return;
+
+   	if (synth->flags & NO_LATCHING_KEYS)
+   	{
+   		int i, p = synth->keypanel;
+
+   		for (i = 0; i < synth->win->app->resources[p].ndevices; i++)
+   			synth->win->app->resources[p].devlocn[i].flags
+   				|= BRIGHTON_NO_TOGGLE;
+
+   		if (synth->keypanel2 < 0)
+   			return;
+
+	   	p = synth->keypanel2;
+
+   		for (i = 0; i < synth->win->app->resources[p].ndevices; i++)
+   			synth->win->app->resources[p].devlocn[i].flags
+	   			|= BRIGHTON_NO_TOGGLE;
+   	}
+}
+
+
 /*
  * These aught to be moved into a more common file, brightonRoutines.c or
  * similar.
@@ -755,8 +781,29 @@ miniInit(brightonWindow *win)
 int
 configureGlobals(guiSynth *synth)
 {
+	if (global.libtest)
+	{
+		int count = 10;
+
+		printf("libtest flagged");
+
+		while (global.libtest)
+		{
+			usleep(100000);
+			if (--count == 0)
+				break;
+		}
+
+		if (count)
+			printf(", cleared\n");
+		else
+			printf("\n");
+	}
+
 	if (!global.libtest)
 	{
+		configureKeylatch(synth);
+
 		if (synth->flags & REQ_MIDI_DEBUG)
 		{
 			bristolMidiSendNRP(global.controlfd, synth->midichannel,
@@ -784,10 +831,10 @@ configureGlobals(guiSynth *synth)
 					BRISTOL_REQ_DEBUG|((synth->flags&REQ_DEBUG_MASK)>>12));
 
 		bristolMidiOption(global.controlfd, BRISTOL_NRP_DEBUG,
-			(synth->flags&(REQ_DEBUG_3|REQ_DEBUG_4))>>14);
+			(synth->flags&REQ_DEBUG_MASK)>>12);
 		if (synth->sid2 != 0)
 			bristolMidiOption(global.manualfd, BRISTOL_NRP_DEBUG,
-				(synth->flags&(REQ_DEBUG_3|REQ_DEBUG_4))>>14);
+				(synth->flags&REQ_DEBUG_MASK)>>12);
 
 		bristolMidiSendNRP(global.controlfd, synth->midichannel,
 			BRISTOL_NRP_GLIDE, synth->glide * C_RANGE_MIN_1 / 30);
@@ -917,6 +964,20 @@ miniConfigure(brightonWindow *win)
 	synth->transpose = 36;
 	synth->keypanel = KEY_PANEL;
 	synth->keypanel2 = -1;
+
+	/*
+	 * We now want to set a couple of parameters provided by switches in the
+	 * 0.9 release but configurable per synth. These are detune and gain to
+	 * start with. Some of this code could be separated as it is likely to be
+	 * common to each synth. These parameters will be sent to the engine using
+	 * midi non-registered parameters. These will be sent as NRP-98/99 and Data
+	 * Entry-6/38. To simplify the interface we should be able to make one call
+	 * send a NRP including the number and its 14 bit value. It is up to the
+	 * interface to decide how to send it depending on whether it is a repeat
+	 * message or not.
+	 */
+	configureGlobals(synth);
+
 	loadMemory(synth, "mini", 0, synth->location, synth->mem.active,
 		FIRST_DEV, 0);
 
@@ -932,18 +993,6 @@ miniConfigure(brightonWindow *win)
 	event.intvalue = 1;
 	brightonParamChange(synth->win, KEY_PANEL, -1, &event);
 
-	/*
-	 * We now want to set a couple of parameters provided by switches in the
-	 * 0.9 release but configurable per synth. These are detune and gain to
-	 * start with. Some of this code could be separated as it is likely to be
-	 * common to each synth. These parameters will be sent to the engine using
-	 * midi non-registered parameters. These will be sent as NRP-98/99 and Data
-	 * Entry-6/38. To simplify the interface we should be able to make one call
-	 * send a NRP including the number and its 14 bit value. It is up to the
-	 * interface to decide how to send it depending on whether it is a repeat
-	 * message or not.
-	 */
-	configureGlobals(synth);
 	return(0);
 }
 
