@@ -706,7 +706,7 @@ brightonApp mixApp = {
 	destroySynth,
 	{1, 0, 2, 1, 5, 520, 0, 0},
 	WIDTH,
-	720,
+	720, 0, 0,
 	CHAN_COUNT + 4, /* panel count == CHAN_COUNT + 4 */
 	{
 		{
