@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -634,7 +633,12 @@ mixerMemory(guiSynth *synth, int op, int subop, int param, void *value)
 		case MM_LOAD:
 			return(loadMixerMemory(synth, value, param));
 		case MM_INIT:
+			/*
+			 * This was orginally a rather dumb typecast
 			return((int) initMixerMemory(param));
+			 * Need to review all of this code as the mixer gets rolled out
+			 */
+			return(0);
 		case MM_SET:
 			return(setMixerMemory((mixerMem *) synth->mem.param,
 				subop, param, value, NULL));
