@@ -886,7 +886,7 @@ obxInit(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) < 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
