@@ -2045,7 +2045,7 @@ obxaInit(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
