@@ -1000,7 +1000,7 @@ odysseyInit(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
