@@ -760,7 +760,7 @@ polyInit(brightonWindow *win)
 
 	synth->win = win;
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	printf("Initialise the poly link to bristol: %p\n", synth->win);
