@@ -758,7 +758,7 @@ poly6Init(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
