@@ -733,7 +733,7 @@ brightonApp poly800App = {
 	midiCallback,
 	destroySynth,
 	{8, 100, 2, 2, 5, 520, 0, 0},
-	1016, 370,
+	1016, 370, 0, 0,
 	3, /* one panel only */
 	{
 		{
