@@ -874,7 +874,7 @@ pro1Init(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
