@@ -621,7 +621,7 @@ prophet52Init(brightonWindow *win)
 
 	synth->win = win;
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	printf("Initialise the prophet52 link to bristol: %p\n", synth->win);
