@@ -668,7 +668,7 @@ realisticConfigure(brightonWindow *win)
 	if (synth->flags & OPERATIONAL)
 		return(0);
 
-printf("going operational\n");
+	printf("going operational\n");
 
 	synth->flags |= OPERATIONAL;
 	synth->keypanel = KEY_PANEL;
@@ -677,7 +677,8 @@ printf("going operational\n");
 /*	loadMemory(synth, "realistic", 0, synth->location, synth->mem.active, */
 /*		FIRST_DEV, 0); */
 
-	loadMemory(synth, "realistic", 0, 0, ACTIVE_DEVS, 0, BRISTOL_FORCE);
+	loadMemory(synth, "realistic", 0, synth->location, ACTIVE_DEVS, 0,
+		BRISTOL_FORCE);
 
 	brightonPut(win,
 		"bitmaps/blueprints/realshade.xpm", 0, 0, win->width, win->height);
