@@ -143,7 +143,7 @@ brightonApp rhodesApp = {
 	rhodesMidiCallback,
 	0,
 	{16, 0, 2, 2, 5, 520, 0, 1},
-	750, 250,
+	750, 250, 0, 0,
 	7, /* panel count */
 	{
 		{
