@@ -93,9 +93,9 @@ cleanupBristol()
 	/*
 	 * We don't need to clean out every synth, we need to cleanout the second
 	 * manual if it is configured, then the controlfd
-	 */
 	bristolMidiSendNRP(global.controlfd, global.synths->sid,
 		BRISTOL_NRP_MIDI_GO, 0);
+	 */
 
 	if ((global.manualfd != 0) && (global.manualfd != global.controlfd))
 	{
@@ -115,8 +115,8 @@ cleanupBristol()
 		127, 0, BRISTOL_EXIT_ALGO);
 	if (global.synths->flags & REQ_DEBUG_MASK)
 		printf("Primary layer removed\n");
-	/* OK, so sleep is lax, we used to wait for a message */
-	bristolMidiRead(global.controlfd, &msg);
+	/* We used to wait for a message however it is of no interest now */
+	//bristolMidiRead(global.controlfd, &msg);
 
 	usleep(250000);
 
@@ -659,76 +659,83 @@ int active, int skip, int flags)
 
 	location += synth->mbi;
 
-	if ((fd = getMemoryLocation(algo, name, location, O_RDONLY)) < 0)
-		return(-1);
+	if (location >= 0)
+	{
+		if ((fd = getMemoryLocation(algo, name, location, O_RDONLY)) < 0)
+			return(-1);
 
-	if (flags & BRISTOL_STAT)
-	{
-		close(fd);
-		return(0);
-	}
-
-	if (read(fd, &tmem.algo[0], 32) < 0)
-	{
-		printf("read failed on params\n");
-		close(fd);
-		return(-1);
-	}
-	if (read(fd, &tmem.name[0], 32) < 0)
-	{
-		printf("read failed on name\n");
-		close(fd);
-		return(-1);
-	}
-	if (read(fd, &tmem.count, 4 * sizeof(short)) < 0)
-	{
-		printf("read failed opts\n");
-		close(fd);
-		return(-1);
-	}
-
-	if (tmem.vers != 0)
-	{
-		/*
-		 * Future revisions to the memory structures should put hooks in here
-		 */
-		printf("read failed: vers %i no supported\n", synth->mem.vers);
-		close(fd);
-		return(-1);
-	}
-
-	if (strcmp(&tmem.algo[0], algo) != 0)
-	{
-		if ((flags & BRISTOL_FORCE) == 0)
+		if (flags & BRISTOL_STAT)
 		{
-			if (tmem.algo[0] == '\0')
-				printf("Attempt to read (noname) into %s algorithm\n", algo);
-			else
-				printf("Attempt to read %s into %s algo\n", &tmem.algo[0],algo);
+			close(fd);
+			return(0);
+		}
 
+		if (read(fd, &tmem.algo[0], 32) < 0)
+		{
+			printf("read failed on params\n");
+			close(fd);
+			return(-1);
+		}
+		if (read(fd, &tmem.name[0], 32) < 0)
+		{
+			printf("read failed on name\n");
+			close(fd);
+			return(-1);
+		}
+		if (read(fd, &tmem.count, 4 * sizeof(short)) < 0)
+		{
+			printf("read failed opts\n");
 			close(fd);
 			return(-1);
 		}
-		sprintf(&synth->mem.algo[0], "%s", algo);
-	} else {
-		sprintf(&synth->mem.algo[0], "%s", &tmem.algo[0]);
-		sprintf(&synth->mem.name[0], "%s", &tmem.name[0]);
-	}
-	synth->mem.count = tmem.count;
-	synth->mem.vers = tmem.vers;
 
-	if (((synth->flags & REQ_DEBUG_MASK) > REQ_MIDI_DEBUG2)
-		&& (synth->mem.active != tmem.active))
-		printf("Active count changed. Overriding\n");
+		if (tmem.vers != 0)
+		{
+			/*
+			 * Future revisions to the memory structures should put hooks in
+			 * here
+			 */
+			printf("read failed: vers %i no supported\n", synth->mem.vers);
+			close(fd);
+			return(-1);
+		}
+
+		if (strcmp(&tmem.algo[0], algo) != 0)
+		{
+			if ((flags & BRISTOL_FORCE) == 0)
+			{
+				if (tmem.algo[0] == '\0')
+					printf("Attempt to read (noname) into %s algorithm\n",
+						algo);
+				else
+					printf("Attempt to read %s into %s algo\n", &tmem.algo[0],
+						algo);
+
+				close(fd);
+				return(-1);
+			}
+			sprintf(&synth->mem.algo[0], "%s", algo);
+		} else {
+			sprintf(&synth->mem.algo[0], "%s", &tmem.algo[0]);
+			sprintf(&synth->mem.name[0], "%s", &tmem.name[0]);
+		}
+		synth->mem.count = tmem.count;
+		synth->mem.vers = tmem.vers;
+
+		if (((synth->flags & REQ_DEBUG_MASK) > REQ_MIDI_DEBUG2)
+			&& (synth->mem.active != tmem.active))
+			printf("Active count changed. Overriding\n");
 /*	synth->mem.active = tmem.active; */
 
-	if (read(fd, &synth->mem.param[skip], active * sizeof(float)) < 0)
-		printf("read failed\n");
+		if (read(fd, &synth->mem.param[skip], active * sizeof(float)) < 0)
+			printf("read failed\n");
 
-	close(fd);
+		close(fd);
 
-	if (flags & BRISTOL_NOCALLS)
-		return(0);
+		if (flags & BRISTOL_NOCALLS)
+			return(0);
+	} else
+		memset(synth->mem.param, 0, active * sizeof(float));
 
 	synth->flags |= MEM_LOADING;
 	/*
@@ -780,6 +787,7 @@ int active, int skip, int flags)
 			}
 		}
 	}
+
 	synth->flags &= ~MEM_LOADING;
 
 	return(0);
@@ -825,6 +833,9 @@ saveMemory(guiSynth *synth, char *algo, char *name, int location, int skip)
 {
 	int fd;
 
+	if (location < 0)
+		return(0);
+
 	location += synth->mbi;
 
 	if ((fd = getMemoryLocation(algo, name, location, O_WRONLY|O_CREAT|O_TRUNC))
