@@ -423,7 +423,7 @@ brightonApp solinaApp = {
 	midiCallback,
 	destroySynth,
 	{-1, 0, 2, 2, 5, 520, 0, 0},
-	600, 200,
+	600, 200, 0, 0,
 	8, /* panel count */
 	{
 		{
