@@ -993,7 +993,7 @@ sonic6Init(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
@@ -1298,6 +1298,7 @@ sonic6Configure(brightonWindow *win)
 		synth->bank = 1;
 		synth->location = 1;
 	}
+
 	loadMemory(synth, "sonic6", 0, initmem, synth->mem.active, FIRST_DEV, 
 		BRISTOL_FORCE);
 
@@ -1305,7 +1306,7 @@ sonic6Configure(brightonWindow *win)
 	/* Tune */
 	event.value = 0.5;
 	brightonParamChange(synth->win, 0, 60, &event);
-	/* Volumee */
+	/* Volume */
 	event.value = 0.5;
 	brightonParamChange(synth->win, 2, 1, &event);
 	/* Glide */
