@@ -1265,7 +1265,7 @@ stratusInit(brightonWindow *win)
 		}
 	}
 
-	if ((initmem = synth->location) <= 0)
+	if ((initmem = synth->location) == 0)
 		initmem = 11;
 
 	synth->win = win;
