@@ -378,7 +378,7 @@ brightonApp voxApp = {
 	midiCallback,
 	destroySynth,
 	{-1, 0, 2, 2, 5, 520, 0, 1},
-	550, 250,
+	550, 250, 0, 0,
 	7, /* panel count */
 	{
 		{
