@@ -275,7 +275,7 @@ brightonApp voyagerApp = {
 	midiCallback,
 	destroySynth,
 	{1, 100, 2, 2, 5, 520, 0, 0},
-	817, 472,
+	817, 472, 0, 0,
 	7, /* one panel only */
 	{
 		{
