@@ -114,8 +114,10 @@ char *helptext = "\nA synthesiser emulation package.\n\
         -rud               - constrain rotary tracking to up/down\n\
         -pixmap            - use the pixmap interface rather than ximage\n\
         -dct <ms>          - double click timeout (250 ms)\n\
-        -tracking          - disable MIDI keyboard tracking in GUI\n\
+        -tracking          - disable MIDI keyboard latching state\n\
+        -keytoggle         - disable MIDI \n\
         -load <m>          - load memory number 'm' (default 0)\n\
+        -neutral           - initialise the emulator with a 'null' patch\n\
         -import <pathname> - import memory from file into synth\n\
         -mbi <m>           - master bank index (0)\n\
         -activesense <m>   - active sense rate (2000 ms)\n\
@@ -160,6 +162,7 @@ char *helptext = "\nA synthesiser emulation package.\n\
             -gui           - don't start gui (only start engine)\n\
             -server        - run engine as a permanant server\n\
             -daemon        - run engine as a detached permanant server\n\
+            -watchdog <s>  - audio thread initialisation timeout (30s)\n\
             -log           - redirect diagnostic to $HOME/.bristol/log\n\
             -syslog        - redirect diagnostic to syslog\n\
             -console       - log all messages to console (must be 1st option)\n\
@@ -168,6 +171,7 @@ char *helptext = "\nA synthesiser emulation package.\n\
             -exit          - terminate all bristol engines and GUI\n\
             -kill <-emu>   - terminate all bristol processes emulating -emu\n\
             -cache <path>  - memory and profile cache location (~/.bristol)\n\
+            -memdump <path>- copy full set of memories to <path>, with -emulate\n\
             -debug <1-16>  - debuging level (0)\n\
             -readme [-<e>] - show readme [for emulator <e>] to console\n\
             -glwf          - global lightweight filters - no overrides\n\
@@ -178,6 +182,7 @@ char *helptext = "\nA synthesiser emulation package.\n\
             -oss           - use OSS defaults for audio and MIDI\n\
             -alsa          - use ALSA defaults for audio and MIDI (default)\n\
             -jack          - use Jack defaults for audio and MIDI\n\
+            -jackstats     - avoid use of bristoljackstats\n\
             -jsmuuid <UUID>- jack session unique identifier\n\
             -jsmfile <path>- jack session setting path\n\
             -jsmd <ms>     - jack session file load delay (5000)\n\
@@ -380,6 +385,45 @@ Corresponding Source conveyed, and Installation Information provided, in accord
 char *summarytext = "\
 arp2600 \
 axxe \
+bassmaker \
+bitone \
+bit99 \
+bit100 \
+BME700 \
+dx \
+explorer \
+hammondB3 \
+juno \
+jupiter8 \
+memoryMoog \
+mini \
+monopoly \
+obx \
+obxa \
+odyssey \
+poly \
+poly800 \
+pro1 \
+prophet \
+prophet10 \
+prophet52 \
+realistic \
+rhodes \
+rhodesbass \
+roadrunner \
+sidney \
+solina \
+sonic6 \
+stratus \
+trilogy \
+vox \
+voxM2 \
+voyager \
+";
+
+char *oldsummarytext = "\
+arp2600 \
+axxe \
 b3 \
 bm \
 bme700 \
@@ -391,7 +435,7 @@ explorer \
 juno \
 jupiter \
 mg1 \
-memory \
+memoryMoog \
 mini \
 monopoly \
 obx \
