@@ -317,7 +317,14 @@ doAudioOps(audioMain *audiomain, float *outbuf, float *startbuf)
 
 			if ((v->flags & BRISTOL_KEYREON) == 0)
 				v->flags |= BRISTOL_KEYON;
+
+			if (v->flags & BRISTOL_KEYREOFF)
+			{
+				v->flags &= ~BRISTOL_KEYREOFF;
+				v->flags |= BRISTOL_KEYOFF|BRISTOL_KEYSUSTAIN;
+			}
 		}
+
 		audiomain->newlast = NULL;
 
 		/*
@@ -338,8 +345,16 @@ doAudioOps(audioMain *audiomain, float *outbuf, float *startbuf)
 	 */
 	while (voice != NULL)
 	{
-		if (voice->baudio == NULL)
+		if ((voice->baudio == NULL)
+			|| (voice->baudio->operate == NULL))
 		{
+			if ((voice->baudio != NULL)
+				&& (voice->baudio->operate == NULL))
+			{
+				printf("this emulator is not implemented\n");
+				voice->baudio->notemap.flags
+					&= ~(BRISTOL_MNL_LNP|BRISTOL_MNL_HNP);
+			}
 			/*
 			 * Unlink this voice
 			 */
@@ -411,7 +426,7 @@ doAudioOps(audioMain *audiomain, float *outbuf, float *startbuf)
 				 */
 				if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
 					printf("overvoice keydone\n");
-				voice->flags |= BRISTOL_KEYDONE;
+				voice->flags |= BRISTOL_KEYOFF;
 				voice = voice->next;
 				continue;
 			}
@@ -623,6 +638,7 @@ doAudioOps(audioMain *audiomain, float *outbuf, float *startbuf)
 		extmult = outbuf;
 
 		gain = thisaudio->gain;
+
 /*
 		if ((gain = thisaudio->gain) == 0)
 			gain = 1.0;
