@@ -115,8 +115,11 @@ audioThread(audioMain *audiomain)
 			audiomain->atStatus = BRISTOL_EXIT;
 
 			printf("pulse audio interface returned\n");
-
+#ifdef MONOLITHIC
+			pthread_exit(&pthreadstatus);
+#else
 			_exit(0);
+#endif
 		}
 
 		return;
@@ -715,6 +718,8 @@ initBristolAudio(audioMain *audiomain, Baudio *baudio)
 	baudio->leftbuf = (float *) bristolmalloc0(audiomain->segmentsize);
 	baudio->rightbuf = (float *) bristolmalloc0(audiomain->segmentsize);
 
+	baudio->glidemax = 5;
+
 	/*
 	 * These will come from some configuration file, eventually.
 	 */
@@ -807,9 +812,9 @@ initBristolAudio(audioMain *audiomain, Baudio *baudio)
 	 * array of pointers to arrays pointing to chars.
 	 */
 	baudio->locals = (char ***)
-		bristolmalloc0(sizeof(void *) * audiomain->voiceCount);
+		bristolmalloc0(sizeof(void *) * BRISTOL_MAXVOICECOUNT);
 	baudio->FXlocals = (char ***)
-		bristolmalloc0(sizeof(void *) * audiomain->voiceCount);
+		bristolmalloc0(sizeof(void *) * BRISTOL_MAXVOICECOUNT);
 
 	for (i = 0; i < audiomain->voiceCount; i++)
 	{
@@ -819,12 +824,32 @@ initBristolAudio(audioMain *audiomain, Baudio *baudio)
 		baudio->FXlocals[i] =
 			(void *) bristolmalloc0(baudio->soundCount * sizeof(void *));
 
+		if (audiomain->effects == NULL) {
+			int i = 5;
+
+			printf("Null audio FX list\n");
+
+			while (audiomain->effects == NULL) {
+				sleep(1);
+				if (--i == 0)
+				{
+					printf("Null audio FX list unrecovered audio thread\n");
+					exit(0);
+				}
+			}
+
+			printf("recovered\n");
+		}
+
 		if ((baudio->effect != NULL) && (baudio->effect[0] != NULL)
 			&& (baudio->soundCount != 0))
 		{
 			op = (audiomain->effects)[(*baudio->effect[0]).index];
-			baudio->FXlocals[i][0]
-				= (char *) bristolmalloc0(op->specs->localsize);
+			if (op && op->specs)
+				baudio->FXlocals[i][0]
+					= (char *) bristolmalloc0(op->specs->localsize);
+			else
+				baudio->FXlocals[i][0] = (char *) bristolmalloc0(256);
 		}
 
 		if ((baudio->soundCount > 1)
@@ -944,11 +969,10 @@ freeBristolAudio(audioMain *audiomain, Baudio *baudio)
 		{
 			/*
 			 * Free the inividual locals.
-			 * This causes some issues with chained effects, the locals list
-			 * gets damaged or reassigned. That will only ever be a problem
-			 * with dynamic changes to the synth configuration, something that 
-			 * people are not doing yet, so going to defer the fix.
 			 */
+			if (baudio->FXlocals[i][0] == NULL)
+				continue;
+
 			for (j = 0; j < baudio->soundCount; j++) {
 				bristolfree(baudio->locals[i][j]);
 				bristolfree(baudio->FXlocals[i][j]);
