@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define BRISTOL_DBG */
@@ -364,26 +363,6 @@ register int count, register float width)
 	return(wtp);
 }
 
-/*
- * As of the first write, 9/11/01, this takes nearly 20mips to operate a single
- * oscillator. Will work on optimisation of the code, using non-referenced 
- * variables in register workspace.
- *
- *	output buffer pointer.
- *	output buffer index.
- *	input buffer index.
- *	wavetable.
- *	wavetable index.
- *	count.
- *	gain.
- *
- * This oscillator is going to have 4 continous controllers for the signal
- * strengths of the different harmonics, 32/16/8/4. It will have different
- * gain levels for the tri and ramp waves. Finally the phase shifting pulse
- * wave will function probably on the lowest selected harmonic at first since
- * we are not going to recalculate it unless the results of two phase shifting
- * pulse harmonics turns out to be seriously attractive.
- */
 static int operate(bristolOP *operator,
 	bristolVoice *voice,
 	bristolOPParams *param,
@@ -463,7 +442,7 @@ static int operate(bristolOP *operator,
 		 * Take a sample from the wavetable into the output buffer, this is
 		 * the combined tri/ramp waveform.
 		 */
-		if (((int) wtp) >= BITONE_WAVE_SZE_M) {
+		if (((int) wtp) == BITONE_WAVE_SZE_M) {
 			ob[obp] += (wt1[0] * (wtp - ((float) ((int) wtp)))
 				+ wt1[(int) wtp] * (1.0 - (wtp - ((float) ((int) wtp)))));
 			sob[obp] = (wt2[0] * (wtp - ((float) ((int) wtp)))
@@ -770,7 +749,7 @@ fillWave(register float *mem, register int count, int type)
 			/*
 			 * Ramp wave
 			 */
-			if (bloflags & BRISTOL_BLO)
+			if (blo.flags & BRISTOL_BLO)
 			{
 				int i;
 
@@ -788,7 +767,7 @@ fillWave(register float *mem, register int count, int type)
 			/* 
 			 * This is a square wave, with decaying plateaus.
 			 */
-			if (bloflags & BRISTOL_BLO)
+			if (blo.flags & BRISTOL_BLO)
 			{
 				for (i = 0;i < count; i++)
 					mem[i] = blosquare[i];
@@ -805,7 +784,7 @@ fillWave(register float *mem, register int count, int type)
 			{
 				int i;
 
-				if (bloflags & BRISTOL_BLO)
+				if (blo.flags & BRISTOL_BLO)
 				{
 					for (i = 0;i < count; i++)
 						mem[i] = blotriangle[i];
