@@ -20,6 +20,7 @@
  */
 
 #include <signal.h>
+#include <strings.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -37,7 +38,7 @@
 #include "bristolmidi.h"
 #include "bristolblo.h"
 
-static char *defaultcdev = "localhost";
+static char defaultcdev[16];
 
 extern int dupfd;
 void inthandler();
@@ -114,7 +115,10 @@ buildCmdLine(audioMain *audiomain, int argc, char **argv)
 	audiomain->cmdline = bristolmalloc0(size + 1);
 
 	printf("%s", argv[0]);
-	sprintf(audiomain->cmdline, "startBristol");
+	if (rindex(argv[0], '/') == NULL)
+		sprintf(audiomain->cmdline, "startBristol");
+	else
+		sprintf(audiomain->cmdline, "%s", rindex(argv[0], '/') + 1);
 
 	for (i = 1; i < argc; i++)
 	{
@@ -173,6 +177,8 @@ main(int argc, char **argv)
 	int bloMin = 3;
 	pid_t cpid;
 	pthread_t audiothread = (pthread_t) NULL, midithread, logthread;
+	int watchdog = 30000000;
+	int exitdecr = 25000;
 
 #ifndef BRISTOL_SEMAPHORE
 	bristolMidiMsg msg;
@@ -231,10 +237,12 @@ main(int argc, char **argv)
 		exit(0);
 	}
 
+#ifndef MONOLITHIC
 	if (argc <= 2) {
 		printf("You probably prefer to use the startBristol script.\n");
 		exit(1);
 	}
+#endif
 
 	/*
 	 * This could be made more intelligent such as a name for what to connect
@@ -252,6 +260,8 @@ main(int argc, char **argv)
 	bristolMidiOption(0, BRISTOL_NRP_SYSID_H, 0x534C);
 	bristolMidiOption(0, BRISTOL_NRP_SYSID_L, 0x6162);
 	audiomain.SysID = 0x534c6162;
+	/* Localhost implies a TCP socket as it is a 'host' */
+	snprintf(defaultcdev, 16, "localhost");
 	audiomain.controldev = defaultcdev;
 
 	while (argc > argCount)
@@ -324,6 +334,12 @@ main(int argc, char **argv)
 			|| (strcmp(argv[argCount], "-server") == 0))
 			audiomain.flags &= ~BRISTOL_MIDI_WAIT;
 
+		if (strcmp(argv[argCount], "-watchdog") == 0)
+		{
+			if (++argCount <= argc)
+				watchdog = atoi(argv[argCount]) * 1000000;
+		}
+
 		if (strcmp(argv[argCount], "-mididev") == 0)
 		{
 			if (++argCount <= argc)
@@ -399,9 +415,6 @@ main(int argc, char **argv)
 					audiomain.flags
 						= (audiomain.flags & ~BRISTOL_AUDIOMASK)|BRISTOL_ALSA;
 					audiomain.audiodev = NULL;
-				} else if (strcmp(argv[argCount], "slab") == 0) {
-					audiomain.flags
-						= (audiomain.flags & ~BRISTOL_AUDIOMASK)|BRISTOL_SLAB;
 				} else if (strcmp(argv[argCount], "jack") == 0) {
 					audiomain.flags
 						= (audiomain.flags & ~BRISTOL_AUDIOMASK)|BRISTOL_JACK;
@@ -409,7 +422,7 @@ main(int argc, char **argv)
 					audiomain.audiodev = argv[0];
 				} else if (strcmp(argv[argCount], "pulsethread") == 0) {
 					audiomain.flags
-						= (audiomain.flags & ~BRISTOL_AUDIOMASK)|BRISTOL_PULSE;
+						= (audiomain.flags & ~BRISTOL_AUDIOMASK)|BRISTOL_PULSE_T;
 					/* Default the devicename, can be overridden later */
 					audiomain.audiodev = argv[0];
 				} else if (strcmp(argv[argCount], "pulse") == 0) {
@@ -452,17 +465,11 @@ main(int argc, char **argv)
 		/*
 		 * This is the TCP control port connection only.
 		 */
-		if (strcmp(argv[argCount], "-port") == 0)
-		{
-			if (++argCount <= argc)
-				audiomain.port = atoi(argv[argCount]);
-		}
+		if ((strcmp(argv[argCount], "-port") == 0) && ((argCount + 1) < argc))
+			audiomain.port = atoi(argv[argCount + 1]);
 
-		if (strcmp(argv[argCount], "-host") == 0)
-		{
-			if (++argCount <= argc)
-				audiomain.controldev = argv[argCount];
-		}
+		if ((strcmp(argv[argCount], "-host") == 0) && ((argCount + 1) <= argc))
+			snprintf(defaultcdev, 16, "%s", argv[argCount + 1]);
 
 		if (strcmp(argv[argCount], "-oss") == 0)
 			audiomain.flags = (audiomain.flags &
@@ -524,7 +531,8 @@ main(int argc, char **argv)
 
 		if ((strcmp(argv[argCount], "-arp2600") == 0)
 			&& (audiomain.flags & BRISTOL_JACK))
-			audiomain.iocount = 4;
+			/* This was '4' but turned out to be a bad default */
+			audiomain.iocount = 0;
 
 		if ((strcmp(argv[argCount], "-multi") == 0) && (argc > argCount)
 			&& (audiomain.flags & BRISTOL_JACK))
@@ -625,6 +633,14 @@ main(int argc, char **argv)
 
 	printf("bristol version %s\n", VERSION);
 
+	if (strncmp("unix:", defaultcdev, 5) == 0)
+	{
+		if (strlen(defaultcdev) == 5)
+			snprintf(defaultcdev, 16, "unix:%i", audiomain.port);
+		else
+			audiomain.port = atoi(&defaultcdev[5]);
+	}
+
 	/* Print the argument list, debug level does not apply here */
 	buildCmdLine(&audiomain, argc, argv);
 
@@ -688,6 +704,10 @@ main(int argc, char **argv)
 	if (audiomain.debuglevel)
 		printf("Got midi thread OK status\n");
 
+#ifdef BRISTOL_SEMAPHORE
+	int exitdecr = 1000000;
+#endif
+
 	while (!exitReq)
 	{
 		/*
@@ -785,6 +805,21 @@ main(int argc, char **argv)
 #endif
 				}
 			}
+			exitdecr = 0;
+		} else if (audiomain.flags & BRISTOL_MIDI_WAIT) {
+			/*
+			 * If we do not get an audio thread start request within an amount
+			 * of time (should be a parameter) and we have not been given the
+			 * daemon flag then we should consider failing and stoping the
+			 * process.
+			 */
+			if ((watchdog -= exitdecr) <= 0) 
+			{
+				printf("init watchdog exception\n");
+				audiomain.atStatus = BRISTOL_FAIL;
+				bristolMidiTerminate();
+			} else if (audiomain.debuglevel > 8)
+				printf("init watchdog %i\n", watchdog);
 		}
 
 		if ((audiomain.atStatus == BRISTOL_FAIL)
@@ -883,7 +918,7 @@ main(int argc, char **argv)
 #endif
 	}
 
-	if (audiomain.flags & BRISTOL_PULSE)
+	if (audiomain.flags & BRISTOL_PULSE_T)
 	{
 		audiomain.atReq = BRISTOL_REQSTOP;
 #ifdef BRISTOL_PA
