@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define DEBUG */
@@ -903,8 +902,8 @@ static bristolBitoneDestroy(audioMain *audiomain, Baudio *baudio)
 	 * The following can be left up to the library. If we free this here then
 	 * we do need to NULL the pointer otherwise glibc may get picky.
 	 */
-	bristolfree(baudio->mixlocals);
-	baudio->mixlocals = NULL;
+	bristolfree(((bmods *) baudio->mixlocals)->lout);
+	bristolfree(((bmods *) baudio->mixlocals)->rout);
 
 	/*
 	 * We need to leave these, we may have multiple invocations running
@@ -990,7 +989,7 @@ bristolBitoneInit(audioMain *audiomain, Baudio *baudio)
 	initSoundAlgo(16,	1, baudio, audiomain, baudio->sound);
 	initSoundAlgo( 1,	2, baudio, audiomain, baudio->sound);
 	initSoundAlgo( 1,	3, baudio, audiomain, baudio->sound);
-	/* Two oscillator - these still need harmonic mods */
+	/* Two oscillator */
 	initSoundAlgo(30,	4, baudio, audiomain, baudio->sound);
 	initSoundAlgo(30,	5, baudio, audiomain, baudio->sound);
 	/* A filter with ADSR */
