@@ -50,7 +50,13 @@ bme700Controller(Baudio *baudio, u_char operator, u_char controller, float value
 
 	switch (controller) {
 		case 0:
-			baudio->glide = value * value * baudio->glidemax;
+			((bme700mods *) baudio->mixlocals)->glide = value * value;
+
+			if (baudio->mixflags & BME700_GLIDE)
+				baudio->glide = ((bme700mods *) baudio->mixlocals)->glide
+					* baudio->glidemax;
+			else
+				baudio->glide = 0;
 			break;
 		case 1:
 			baudio->gtune = 1.0
@@ -130,6 +136,12 @@ bme700Controller(Baudio *baudio, u_char operator, u_char controller, float value
 				baudio->mixflags &= ~BME700_GLIDE;
 			else
 				baudio->mixflags |= BME700_GLIDE;
+
+			if (baudio->mixflags & BME700_GLIDE)
+				baudio->glide = ((bme700mods *) baudio->mixlocals)->glide
+					* baudio->glidemax;
+			else
+				baudio->glide = 0;
 			break;
 
 		case 16:
