@@ -344,7 +344,7 @@ bristolVoice *voice, register float *startbuf)
 	{
 		pbHLast += (*hpf - pbHLast) * 0.2;
 		*hpf -= pbHLast;
-		*hpf++ *= 2;
+		*hpf++ *= 0.8;
 	}
 
 	audiomain->palette[(*baudio->sound[5]).index]->specs->io[0].buf =
@@ -369,8 +369,12 @@ bristolVoice *voice, register float *startbuf)
 
 /*
  * Operate one hammond voice will function as the upper manual for a B3. If
- * requested there may also be a second manual active, with limited 
- * functionality regarding percussives, etc.
+ * requested there may also be a second manual active, it will have limited 
+ * functionality regarding percussives, etc. We should rewrite this, the voices
+ * should not actually produce any sound: they should build a gaintable for the
+ * harmonics that need to be tapped off the gearbox with offsets for new notes.
+ * Then we call therequiem() that will generate any wheels that have non-zero
+ * gain and mix them all down.
  */
 int
 operateOneHammondVoice(audioMain *audiomain, Baudio *baudio,
@@ -402,7 +406,7 @@ bristolVoice *voice, register float *startbuf)
 	audiomain->palette[(*baudio->sound[0]).index]->specs->io[2].buf = tmpbuf2;
 
 	(*baudio->sound[0]).operate(
-		(audiomain->palette)[5],
+		(audiomain->palette)[B_HAMMOND],
 		voice,
 		(*baudio->sound[0]).param,
 		voice->locals[voice->index][0]);
@@ -414,7 +418,7 @@ bristolVoice *voice, register float *startbuf)
 	 */
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[0].buf = tmpbuf1;
 	(*baudio->sound[1]).operate(
-		(audiomain->palette)[1],
+		(audiomain->palette)[B_ENV],
 		voice,
 		(*baudio->sound[1]).param,
 		voice->locals[voice->index][1]);
@@ -429,7 +433,7 @@ bristolVoice *voice, register float *startbuf)
 		= baudio->leftbuf;
 
 	(*baudio->sound[2]).operate(
-		(audiomain->palette)[2],
+		(audiomain->palette)[B_DCA],
 		voice,
 		(*baudio->sound[2]).param,
 		voice->locals[voice->index][2]);
@@ -448,10 +452,11 @@ bristolVoice *voice, register float *startbuf)
 			= baudio->leftbuf;
 
 	(*baudio->sound[2]).operate(
-		(audiomain->palette)[2],
+		(audiomain->palette)[B_DCA],
 		voice,
 		(*baudio->sound[2]).param,
 		voice->locals[voice->index][2]);
+
 	return(0);
 }
 
@@ -494,7 +499,7 @@ bristolVoice *voice, register float *startbuf)
 			= tmpbuf3;
 
 		(*baudio->sound[3]).operate(
-			(audiomain->palette)[5],
+			(audiomain->palette)[B_HAMMOND],
 			voice,
 			(*baudio->sound[3]).param,
 			voice->locals[voice->index][3]);
@@ -512,7 +517,7 @@ bristolVoice *voice, register float *startbuf)
 			= tmpbuf3;
 
 		(*baudio->sound[0]).operate(
-			(audiomain->palette)[5],
+			(audiomain->palette)[B_HAMMOND],
 			voice,
 			(*baudio->sound[0]).param,
 			voice->locals[voice->index][0]);
@@ -525,7 +530,7 @@ bristolVoice *voice, register float *startbuf)
 	 */
 	audiomain->palette[(*baudio->sound[1]).index]->specs->io[0].buf = tmpbuf1;
 	(*baudio->sound[1]).operate(
-		(audiomain->palette)[1],
+		(audiomain->palette)[B_ENV],
 		voice,
 		(*baudio->sound[1]).param,
 		voice->locals[voice->index][1]);
@@ -539,7 +544,7 @@ bristolVoice *voice, register float *startbuf)
 	audiomain->palette[(*baudio->sound[2]).index]->specs->io[2].buf = tmpbuf4;
 
 	(*baudio->sound[2]).operate(
-		(audiomain->palette)[2],
+		(audiomain->palette)[B_DCA],
 		voice,
 		(*baudio->sound[2]).param,
 		voice->locals[voice->index][2]);
@@ -670,19 +675,19 @@ printf("initialising one hammond second manual\n");
 	/*
 	 * Hammond oscillator
 	 */
-	initSoundAlgo(5, 0, baudio, audiomain, baudio->sound);
+	initSoundAlgo(B_HAMMOND, 0, baudio, audiomain, baudio->sound);
 	/*
 	 * Envelope for note_on conditioning.
 	 */
-	initSoundAlgo(1, 1, baudio, audiomain, baudio->sound);
+	initSoundAlgo(B_ENV, 1, baudio, audiomain, baudio->sound);
 	/*
 	 * this envelope needs an amp.
 	 */
-	initSoundAlgo(2, 2, baudio, audiomain, baudio->sound);
+	initSoundAlgo(B_DCA, 2, baudio, audiomain, baudio->sound);
 	/*
 	 * Hammond oscillator
 	 */
-	initSoundAlgo(5, 3, baudio, audiomain, baudio->sound);
+	initSoundAlgo(B_HAMMOND, 3, baudio, audiomain, baudio->sound);
 
 	baudio->param = hammondGlobalController;
 	baudio->destroy = destroyOneHammondB3Voice;
