@@ -44,7 +44,13 @@ u_char operator, float value)
 		baudio->extgain = value;
 
 	if (controller == 9)
-		baudio->glide = value * value * baudio->glidemax;
+	{
+		if (baudio->glidemax == 0)
+			/* Take the default glide value */
+			baudio->glide = value * value * 5.0;
+		else
+			baudio->glide = value * value * baudio->glidemax;
+	}
 
 	if (controller == 10)
 	{
