@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define DEBUG */
@@ -584,7 +583,7 @@ bristolVoice *voice, register float *startbuf)
 	 * This is mostly wrong. Most of the buttons taken as filter mods were
 	 * actually mixing options into the filter.
 	 */
-	bufmerge(oscabuf, 128.0, oscbbuf, 128.0, samplecount);
+	bufmerge(oscabuf, 64.0, oscbbuf, 64.0, samplecount);
 
 	/*
 	 * Run the mixed oscillators into the filter. Input and output buffers
@@ -647,18 +646,18 @@ bristolVoice *voice, register float *startbuf)
 	 */
 	for (;samplecount > 0; samplecount-=8)
 	{
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
-		*rbuf++ = *lbuf++ * g;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
+		*rbuf++ = *lbuf++ * g * 2;
 	}
 
 	samplecount = audiomain->samplecount;
-	g = 1.0f - g;
+	g = (1.0f - g) * 2;
 	lbuf = baudio->leftbuf;
 	for (;samplecount > 0; samplecount-=8)
 	{
