@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -80,7 +79,7 @@ poly800Controller(Baudio *baudio, u_char operator, u_char controller, float valu
 			alterAllNotes(baudio);
 			break;
 		case 2:
-			P800LOCAL->volume = value * 2;
+			P800LOCAL->volume = value * 4;
 			break;
 		case 3:
 			if (value < 0.5)
@@ -588,12 +587,6 @@ static bristolPoly800Destroy(audioMain *audiomain, Baudio *baudio)
 {
 	printf("removing one poly800\n");
 
-	/*
-	 * We need to leave these, we may have multiple invocations running
-	 */
-	return(0);
-
-
 	bristolfree(P800LOCAL->freqbuf);
 	bristolfree(P800LOCAL->oscabuf);
 	bristolfree(P800LOCAL->oscbbuf);
@@ -661,18 +654,30 @@ bristolPoly800Init(audioMain *audiomain, Baudio *baudio)
 	baudio->mixlocals = (float *) bristolmalloc0(sizeof(p800mods));
 	((p800mods *) baudio->mixlocals)->voicecount = baudio->voicecount;
 
-	P800LOCAL->freqbuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->oscabuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->oscbbuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->adsrbuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->outbuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->zerobuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->scratch = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->syncbuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->pwmbuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->lfobuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->noisebuf = (float *) bristolmalloc0(audiomain->segmentsize);
-	P800LOCAL->filtbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->freqbuf == NULL)
+		P800LOCAL->freqbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->oscabuf == NULL)
+		P800LOCAL->oscabuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->oscbbuf == NULL)
+		P800LOCAL->oscbbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->adsrbuf == NULL)
+		P800LOCAL->adsrbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->outbuf == NULL)
+		P800LOCAL->outbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->zerobuf == NULL)
+		P800LOCAL->zerobuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->scratch == NULL)
+		P800LOCAL->scratch = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->syncbuf == NULL)
+		P800LOCAL->syncbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->pwmbuf == NULL)
+		P800LOCAL->pwmbuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->lfobuf == NULL)
+		P800LOCAL->lfobuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->noisebuf == NULL)
+		P800LOCAL->noisebuf = (float *) bristolmalloc0(audiomain->segmentsize);
+	if (P800LOCAL->filtbuf == NULL)
+		P800LOCAL->filtbuf = (float *) bristolmalloc0(audiomain->segmentsize);
 
 	return(0);
 }
