@@ -110,7 +110,7 @@ baudio->effect[0]->param->param[5].float_val);
 				value * CONTROLLER_RANGE;
 			break;
 		case 7:
-			((roadrunnermods *) baudio->mixlocals)->vibrato = value;
+			((roadrunnermods *) baudio->mixlocals)->vibrato = value * 0.25;
 			break;
 		case 8:
 			((roadrunnermods *) baudio->mixlocals)->tremelo = value;
