@@ -1422,9 +1422,11 @@ bristolVoice *voice, register float *startbuf)
 				(tmp3 >> 8) & 0x0f);
 		}
 
+		pitch = baudio->pitchwheel;
+
 		if (smods->modrouting & S_MOD_PITCH)
 		{
-			if ((pitch = (baudio->contcontroller[1] - 0.5) * 2) != 0)
+			if ((pitch += (baudio->contcontroller[1] - 0.5) * 2) != 0)
 			{
 				pitch = powf(baudio->note_diff, pitch * 2);
 
