@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define BRISTOL_DBG */
@@ -265,7 +264,7 @@ register int count, register int width)
 		if ((wtpSqr = wtp + wtpSqr) >= CS80_WAVE_SZE)
 			wtpSqr -= CS80_WAVE_SZE;
 
-		if (wtp >= CS80_WAVE_SZE_M)
+		if (wtp == CS80_WAVE_SZE_M)
 			ob[obp] += (ramp[(int) wtp] + (ramp[0] - ramp[(int) wtp])
 				* gdelta) * gain;
 		else
@@ -273,7 +272,7 @@ register int count, register int width)
 				(ramp[(int) wtp] + ((ramp[(int) wtp + 1] - ramp[(int) wtp])
 				* gdelta)) * gain;
 
-		if (wtpSqr >= CS80_WAVE_SZE_M)
+		if (wtpSqr == CS80_WAVE_SZE_M)
 			ob[obp] -= (ramp[(int) wtpSqr] + (ramp[0] - ramp[(int) wtpSqr])
 				* gdelta) * gain;
 		else
@@ -678,7 +677,7 @@ fillWave(register float *mem, register int count, int type)
 			 * 2PI radians in a full sine wave. Thus we take
 			 * 		(2PI * i / count) * 2048.
 			 */
-			if (bloflags & BRISTOL_BLO)
+			if (blo.flags & BRISTOL_BLO)
 			{
 				int i;
 
@@ -692,7 +691,7 @@ fillWave(register float *mem, register int count, int type)
 			/*
 			 * Ramp wave
 			 */
-			if (bloflags & BRISTOL_BLO)
+			if (blo.flags & BRISTOL_BLO)
 			{
 				int i;
 
@@ -710,7 +709,7 @@ fillWave(register float *mem, register int count, int type)
 			/* 
 			 * This is a square wave, with decaying plateaus.
 			 */
-			if (bloflags & BRISTOL_BLO)
+			if (blo.flags & BRISTOL_BLO)
 			{
 				for (i = 0;i < count; i++)
 					mem[i] = blosquare[i];
@@ -727,7 +726,7 @@ fillWave(register float *mem, register int count, int type)
 			{
 				int i;
 
-				if (bloflags & BRISTOL_BLO)
+				if (blo.flags & BRISTOL_BLO)
 				{
 					for (i = 0;i < count; i++)
 						mem[i] = blotriangle[i];
