@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define BRISTOL_DBG */
@@ -46,7 +45,7 @@ static float note_diff;
  */
 #define OPNAME "DX OP"
 #define OPDESCRIPTION "FM Operator"
-#define PCOUNT 8
+#define PCOUNT 12
 #define IOCOUNT 2
 
 #define DXOP_IN_IND 0
@@ -54,6 +53,19 @@ static float note_diff;
 
 #define DXOP_WAVE_COUNT 6
 
+#define DXOP_TRANSPOSE	0
+#define DXOP_TUNE		1
+#define DXOP_ATTACK		2
+#define DXOP_DECAY		3
+#define DXOP_SUSTAIN	4
+#define DXOP_RELEASE	5
+#define DXOP_GAIN		6
+#define DXOP_VELOCITY	7
+#define DXOP_OGC		8
+#define DXOP_L1			9
+#define DXOP_ATTACK2	10
+#define DXOP_L2			11
+
 static void fillWave();
 
 /*
@@ -184,18 +196,14 @@ static int param(bristolOP *operator, bristolOPParams *param,
 		case 2: /* Attack */
 			//param->param[index].float_val = value * value;
 			offset = (value * value * (CONTROLLER_RANGE - 1)) + 1;
-			param->param[index].float_val = gainTable[offset].rate;
-			break;
-		case 11: /* Attack2 */
-			//param->param[9].float_val = value * value;
-			offset = (value * value * (CONTROLLER_RANGE - 1)) + 1;
+			if (offset >= CONTROLLER_RANGE)
+				offset = CONTROLLER_RANGE - 1;
 			param->param[index].float_val = gainTable[offset].rate;
 			break;
 		case 3: /* Decay */
 			param->param[index].float_val = gainTable[offset].rate;
 			break;
 		case 4:
-			offset = value * (CONTROLLER_RANGE - 1);
 			/*
 			 * Sustain
 			 *
@@ -205,6 +213,9 @@ static int param(bristolOP *operator, bristolOPParams *param,
 			 * The gain tables are fine for frequency adjustments, but do 
 			 * not work well for gain here. Hence
 			 */
+			offset = value * (CONTROLLER_RANGE - 1);
+			if (offset >= CONTROLLER_RANGE)
+				offset = CONTROLLER_RANGE - 1;
 			param->param[index].float_val = value * BRISTOL_VPO;
 			break;
 		case 5:
@@ -229,36 +240,44 @@ static int param(bristolOP *operator, bristolOPParams *param,
 				param->param[index].int_val = 1;
 			param->param[index].float_val = value;
 			break;
-		case 9:
+		case 8:
 			/*
-			 * Hm, this is outside of the spec, but it works.....
+			 * Output gain control
 			 */
-			if (value == 0)
-				param->param[6].int_val = 0;
-			else
-				param->param[6].int_val = 1;
+			if (value == 0) {
+				param->param[index].int_val = 0;
+				param->param[index].float_val = 0;
+			} else {
+				param->param[index].int_val = 1;
+				param->param[index].float_val = 1.0;
+			}
 			break;
-		case 10:
+		case 9:
 			/*
 			 * These are L1-A-L2 for envelope. Have to look into how to pass
 			 * them through to the envelope as a parameter as we only have
 			 * 8 available at the moment.
+			offset = value * (CONTROLLER_RANGE - 1);
+			param->param[index].float_val = value * BRISTOL_VPO;
 			 */
-			offset = value * (CONTROLLER_RANGE - 1);
-			param->param[8].float_val = gainTable[offset].gain * BRISTOL_VPO;
-			param->param[8].float_val = value * BRISTOL_VPO;
+			param->param[index].float_val = value * BRISTOL_VPO;
 			break;
-		case 12:
-			offset = value * (CONTROLLER_RANGE - 1);
-			param->param[10].float_val = gainTable[offset].gain * BRISTOL_VPO;
-			param->param[10].float_val = value * BRISTOL_VPO;
+		case 10: /* Attack2 */
+			//param->param[9].float_val = value * value;
+			offset = (value * value * (CONTROLLER_RANGE - 1)) + 1;
+			if (offset >= CONTROLLER_RANGE)
+				offset = CONTROLLER_RANGE - 1;
+			param->param[index].float_val = gainTable[offset].rate;
+			break;
+		case 11:
+			param->param[index].float_val = value * BRISTOL_VPO;
 			break;
 	}
 
 	return(0);
 }
 
-static float scale = 0.0000000001; // 0.000000001;
+//static float scale = 0.0000000001; // 0.000000001;
 static int dngx1 = 0x67452301;
 static int dngx2 = 0xefcdab89;
 
@@ -308,7 +327,8 @@ static int operate(bristolOP *operator,
 	ob = specs->spec.io[DXOP_OUT_IND].buf;
 	wt = specs->wave[0];
 	wtp = local->wtp;
-	transp = param->param[0].float_val * param->param[1].float_val;
+	transp = param->param[DXOP_TRANSPOSE].float_val
+		* param->param[DXOP_TUNE].float_val;
 	wtp = local->wtp;
 	cgain = local->cgain;
 	egain = local->egain;
@@ -318,15 +338,15 @@ static int operate(bristolOP *operator,
 	if (ib[0] > 10000)
 		ib[0] = ib[1];
 
-	attack = param->param[2].float_val;
-	decay = param->param[3].float_val;
-	sustain = 1.0 + param->param[4].float_val;
-	release = param->param[5].float_val;
+	attack = param->param[DXOP_ATTACK].float_val;
+	decay = param->param[DXOP_DECAY].float_val;
+	sustain = 1.0 + param->param[DXOP_SUSTAIN].float_val;
+	release = param->param[DXOP_RELEASE].float_val;
 
 	/* For extra stage */
-	L1 = param->param[8].float_val;
-	attack2 = param->param[9].float_val;
-	L2 = param->param[10].float_val;
+	L1 = param->param[DXOP_L1].float_val;
+	attack2 = param->param[DXOP_ATTACK2].float_val;
+	L2 = param->param[DXOP_L2].float_val;
 
 	/*
 	 * If the first level is zero, go into compatability mode, ADSR
@@ -355,14 +375,16 @@ static int operate(bristolOP *operator,
 	 *
 	 */
 	gain =
-		param->param[7].float_val * voice->velocity * param->param[6].float_val
-		+ (1 - param->param[7].float_val) * param->param[6].float_val;
+		param->param[DXOP_VELOCITY].float_val
+			* voice->velocity * param->param[DXOP_GAIN].float_val
+		+ (1 - param->param[DXOP_VELOCITY].float_val)
+			* param->param[DXOP_GAIN].float_val;
 
 	/*
 	 * Going to adjust gain based on continuous controllers, if we have flagged
 	 * ogc as a modified variable.
 	 */
-	if (param->param[6].int_val)
+	if (param->param[DXOP_OGC].int_val)
 		gain *= voice->baudio->contcontroller[1];
 
 	/*
@@ -390,6 +412,16 @@ static int operate(bristolOP *operator,
 		rampup = 1;
 		wtp = 0;
 		local->cstate = STATE_ATTACK;
+
+		if ((~voice->flags & BRISTOL_KEYREON) &&
+			(voice->offset > 0) && (voice->offset < count))
+		{
+			if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				printf("envelope trigger offset %i frames\n", voice->offset);
+
+			count -= voice->offset;
+			obp += voice->offset;
+		}
 	} else if (voice->flags & BRISTOL_KEYREON) {
 /* printf("note RE on\n"); */
 		local->cstate = STATE_ATTACK;
@@ -1080,6 +1112,34 @@ dxopinit(bristolOP **operator, int index, int samplerate, int samplecount)
 	specs->spec.param[7].high = 1;
 	specs->spec.param[7].flags = BRISTOL_BUTTON;
 
+	specs->spec.param[8].pname = "OGC";
+	specs->spec.param[8].description = "Output gain control";
+	specs->spec.param[8].type = BRISTOL_INT;
+	specs->spec.param[8].low = 0;
+	specs->spec.param[8].high = 1;
+	specs->spec.param[8].flags = BRISTOL_BUTTON;
+
+	specs->spec.param[9].pname = "L1";
+	specs->spec.param[9].description = "First envelope attack level";
+	specs->spec.param[9].type = BRISTOL_FLOAT;
+	specs->spec.param[9].low = 0;
+	specs->spec.param[9].high = 1;
+	specs->spec.param[9].flags = BRISTOL_ROTARY|BRISTOL_SLIDER;
+
+	specs->spec.param[10].pname = "Attack2";
+	specs->spec.param[10].description = "Second envelope attack rate";
+	specs->spec.param[10].type = BRISTOL_FLOAT;
+	specs->spec.param[10].low = 0;
+	specs->spec.param[10].high = 1;
+	specs->spec.param[10].flags = BRISTOL_ROTARY|BRISTOL_SLIDER;
+
+	specs->spec.param[11].pname = "L2";
+	specs->spec.param[11].description = "Second envelope attack level";
+	specs->spec.param[11].type = BRISTOL_FLOAT;
+	specs->spec.param[11].low = 0;
+	specs->spec.param[11].high = 1;
+	specs->spec.param[11].flags = BRISTOL_ROTARY|BRISTOL_SLIDER;
+
 	/*
 	 * Now fill in the dxop IO specs.
 	 */
