@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define BRISTOL_DBG */
@@ -133,7 +132,7 @@ static int reset(bristolOP *operator, bristolOPParams *param)
 static int param(bristolOP *operator, bristolOPParams *param,
 	unsigned char index, float value)
 {
-	int ivalue = value * C_RANGE_MIN_1;
+	//int ivalue = value * C_RANGE_MIN_1;
 
 #ifdef BRISTOL_DBG
 	printf("env5param(%i, %f)\n", index, value);
@@ -253,6 +252,16 @@ param->param[LEVEL_3].float_val,
 param->param[RATE_3].float_val,
 param->param[LEVEL_4].float_val);
 */
+		if ((~voice->flags & BRISTOL_KEYREON) &&
+			(voice->offset > 0) && (voice->offset < count))
+		{
+			if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				printf("envelope trigger offset %i frames\n", voice->offset);
+
+			memset(ob, 0.0f, voice->offset * sizeof(float));
+			ob += voice->offset;
+			count -= voice->offset;
+		}
 	}
 
 	while (count-- > 0)
