@@ -63,7 +63,19 @@
 
 static float srate;
 
-#define getcoff(c, k) ((c*c)*(1.0f-k)*20000 + k*4*voice->cFreq) / srate
+/*
+ * When this uses cfreq we get very good keyboard tracking as cfreq is a true
+ * frequency mapping. This filter is supposed to be used with the cFreq tables
+ * which do not have that same mapping - they are buffer strides rather than
+ * frequency tables and this needs to be corrected here as the use of cfreq
+ * causes cutoff jumps when glide is applied.
+ *
+ * cFreq = 1024 * cfreq / srate
+ * cfreq = cFreq * srate / 1024
+ * cfreq = cFreq * srate / 1024
+ */
+//#define getcoff(c, k) ((c*c)*(1.0f-k)*20000 + k*4*(voice->cFreq * srate / 1024)) / srate
+#define getcoff(c, k) ((c*c)*(1.0f-k)*20000.0f + voice->cFreq*k*srate*0.00390625f) / srate
 
 //#define TANHF(x) btanhf(voice->baudio->mixflags, x)
 #define TANHF(x) btanhf(mode, x)
@@ -202,6 +214,9 @@ param(bristolOP *operator, bristolOPParams *param,
 	printf("param(%x, %f)\n", index, value);
 #endif
 
+	if (blo.flags & BRISTOL_LWF)
+		param->param[4].int_val = 0;
+
 	switch (index) {
 		case 0:
 		{
