@@ -226,7 +226,7 @@ static int param(bristolOP *operator, bristolOPParams *param,
 			buildHammondSound(operator, -1);
 			break;
 		case 6: /* click */
-			param->param[index].float_val = value * 0.25;
+			param->param[index].float_val = value * value * 0.25;
 			break;
 		case 7: /* Algo */
 			param->param[index].int_val = value * CONTROLLER_RANGE;
@@ -287,6 +287,21 @@ static int operate(bristolOP *operator,
 
 	wtp = local->wtp;
 
+	/*
+	 * Go jumping through the wavetable, with each jump defined by the value
+	 * given on our input line.
+	 *
+	 * Make sure we fill one output buffer.
+	 *
+	 * The '-36' may look odd, but the tonewheel generator does not use MIDI
+	 * note indeces and this puts the key.key back into the gearing numbers.
+	 */
+	if (param->param[7].int_val) {
+		preach(ob, pb, voice->key.key - 36, param->param[2].mem,
+			param->param[3].mem, count, gain, damp, param->param[6].float_val,
+			voice->flags, voice->velocity);
+	} else {
+
 		/*
 		 * Click may be in multiple stages - each click array is 2k samples,
 		 * so if our sample block size is less than this we need to hit
@@ -316,20 +331,6 @@ static int operate(bristolOP *operator,
 			clickset[voice->key.key] += count;
 		}
 
-	/*
-	 * Go jumping through the wavetable, with each jump defined by the value
-	 * given on our input line.
-	 *
-	 * Make sure we fill one output buffer.
-	 *
-	 * The '-36' may look odd, but the tonewheel generator does not use MIDI
-	 * note indeces and this puts the key.key back into the gearing numbers.
-	 */
-	if (param->param[7].int_val) {
-		preach(ob, pb, voice->key.key - 36, param->param[2].mem,
-			param->param[3].mem, count, gain, damp, param->param[6].float_val,
-			voice->flags, voice->velocity);
-	} else {
 		for (obp = 0; obp < count;)
 		{
 			/*
@@ -452,7 +453,7 @@ hammondinit(bristolOP **operator, int index, int samplerate, int samplecount)
 	specs->spec.param[1].high = 1;
 	specs->spec.param[1].flags = BRISTOL_ROTARY|BRISTOL_SLIDER;
 
-	specs->spec.param[2].pname = "oscilator";
+	specs->spec.param[2].pname = "oscillator";
 	specs->spec.param[2].description = "Harmonic content definition";
 	specs->spec.param[2].type = BRISTOL_INT;
 	specs->spec.param[2].low = 0;
