@@ -211,9 +211,10 @@ static int param(bristolOP *operator, bristolOPParams *param,
 				param->param[5].float_val, specs->wave[4]);
 			break;
 		case 6: /* mix sub square */
-			param->param[index].float_val = value * 2;
+			param->param[index].float_val = value * 4;
 			break;
 		case 7: /* mix PWM square */
+printf("junodcoparam(%i, %f)\n", 3, param->param[3].float_val);
 			if (value == 0)
 				param->param[index].int_val = 0;
 			else
@@ -291,7 +292,7 @@ static int operate(bristolOP *operator,
 	width = param->param[0].float_val;
 	dosquare = param->param[7].int_val;
 	wtp = local->wtp;
-	gain = param->param[3].float_val;
+	gain = param->param[3].float_val * 2;
 	subgain = param->param[6].float_val;
 	transp = param->param[1].float_val * param->param[2].float_val;
 	wtp = local->wtp;
@@ -341,11 +342,11 @@ static int operate(bristolOP *operator,
 			{
 				if (cpwm <= 0)
 					cpwm = BRISTOL_SQR;
-				ob[obp] += (cpwm * 0.98) * gain;
+				ob[obp] += (cpwm * 0.98) * gain * 4;
 			} else {
 				if (cpwm > 0)
 					cpwm = -BRISTOL_SQR;
-				ob[obp] += (cpwm * 0.98) * gain;
+				ob[obp] += (cpwm * 0.98) * gain * 4;
 			}
 		}
 		subw *= 0.98;
