@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /*#define BRISTOL_DBG */
@@ -200,7 +199,7 @@ static int operate(bristolOP *operator,
 	void *lcl)
 {
 	bristolLFOlocal *local = lcl;
-	register int obp, count;
+	register int obp = 0, count;
 	register float *ib, *ob, *sb, *shb, *wt, *wt2, wtp, freq, sandh;
 	register float *sine, *wt3, *ramp, *dramp, *wt4, *wt5;
 	bristolLFO *specs;
@@ -239,15 +238,39 @@ static int operate(bristolOP *operator,
 		+ voice->velocity * param->param[2].float_val
 		+ voice->baudio->contcontroller[1] * param->param[3].float_val;
 
+	/*
+	 * There is some awkward logic here. The sync flags was typically only
+	 * available on mono synths but we are trying to be poly. This implies that
+	 * LFO sync to each reon (restruck key) will give choppy results if there
+	 * is only one LFO per emulator. If there is one per voice then we perhaps
+	 * do want this enabled.
+	 */
 	if (((voice->flags & BRISTOL_KEYON) || (voice->flags & BRISTOL_KEYREON))
 		&& (param->param[1].int_val != 0))
+	{
 		wtp = 0;
 
+		/* if ((~voice->flags & BRISTOL_KEYREON) && */
+		if ((voice->offset > 0) && (voice->offset < count))
+		{
+			if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				printf("lfo trigger offset %i frames\n", voice->offset);
+
+			obp += voice->offset;
+			memset(ob, 0.0f, voice->offset * sizeof(float));
+			memset(sb, 0.0f, voice->offset * sizeof(float));
+			memset(sine, 0.0f, voice->offset * sizeof(float));
+			memset(ramp, 0.0f, voice->offset * sizeof(float));
+			memset(dramp, 0.0f, voice->offset * sizeof(float));
+			memset(shb, 0.0f, voice->offset * sizeof(float));
+		}
+	}
+
 	/*
 	 * Go jumping through the wavetable, with each jump defined by the value
 	 * given on our input line, making sure we fill one output buffer.
 	 */
-	for (obp = 0; obp < count; obp++)
+	for (; obp < count; obp++)
 	{
 		/*
 		 * Take a sample from the wavetable into the output buffer.
