@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,12 +15,11 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
-/*#define DEBUG */
+//#define DEBUG
 
 #include <math.h>
 
@@ -86,6 +85,7 @@ findBristolAudio(Baudio *baudio, int id, int channel)
 
 /*	if ((baudio->controlid == id) */
 /*		&& (baudio->midichannel == channel)) */
+
 	if (baudio->sid == id)
 		return(baudio);
 
@@ -104,17 +104,25 @@ midiPolyPressure(audioMain *audiomain, bristolMidiMsg *msg)
 
 	voice = audiomain->playlist;
 
-	/*
-	 * Find this note, and adjust its pressure settings.
-	 */
-	while ((voice = findVoice(voice, msg->params.pressure.key, msg->channel))
-		!= NULL)
+	while (voice != NULL)
 	{
-		if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
-			bristolMidiPrint(msg);
-		voice->pressure.pressure = msg->params.pressure.pressure;
-		voice->press = ((float) msg->params.pressure.pressure) / 127;
+		if ((voice->baudio != NULL)
+			&& ((voice->baudio->midichannel == msg->channel)
+				|| (voice->baudio->midichannel == BRISTOL_CHAN_OMNI))
+			&& (voice->keyid == msg->params.pressure.key))
+		{
+			if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				printf("midiPolyPressure(%i, %i)\n",
+					msg->params.pressure.key, msg->params.pressure.pressure);
+			if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG2)
+				bristolMidiPrint(msg);
+			voice->pressure.pressure = msg->params.pressure.pressure;
+			voice->press = ((float) msg->params.pressure.pressure) / 127;
+		}
+
+		voice = voice->next;
 	}
+
 	return(0);
 }
 
@@ -183,8 +191,11 @@ midiControl(audioMain *audiomain, bristolMidiMsg *msg)
 		 * values into our contcontroller structure even if we have a callback.
 		 */
 
-		if ((c_id >= 0) && (c_id < 128))
+		if ((c_id >= 0) && (c_id < MIDI_CONTROLLER_COUNT))
 			baudio->contcontroller[c_id] = ((float) c_val) / 127;
+		else if (baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+			printf("requested to fill cc %i\n", c_id);
+
 		bristolMidiToGM2(baudio->GM2values, baudio->midimap, baudio->valuemap,
 			msg);
 
@@ -251,8 +262,11 @@ msg->GM2.intvalue,
 					/*
 					 * These have to be enabled
 					 */
-					if ((baudio->midiflags & BRISTOL_MIDI_NRP_ENABLE) == 0)
+					if (~baudio->midiflags & BRISTOL_MIDI_NRP_ENABLE)
+					{
+						baudio = baudio->next;
 						continue;
+					}
 
 					baudio->param(baudio,
 						msg->GM2.coarse >> 7, msg->GM2.coarse & 0x7f,
@@ -278,6 +292,7 @@ msg->GM2.intvalue,
 		 */
 		sustainedNotesOff(audiomain, msg->channel);
 	}
+
 	return(0);
 }
 
@@ -291,8 +306,11 @@ midiProgram(audioMain *audiomain, bristolMidiMsg *msg)
 	 * through to the GUI, or the GUI should register for a midi pipe as well
 	 * and do the other necessary things. I think I actually prefer the latter,
 	 * since having a passthrough here would only be one special case.
-	 */
+	 *
+	 * 0.40.6 should have bidirectional passthrough, removed the message as it
+	 * is superfluous.
 	printf("MIDI Program changes are in the GUI\n");
+	 */
 
 	return(0);
 }
@@ -304,28 +322,35 @@ midiChannelPressure(audioMain *audiomain, bristolMidiMsg *msg)
 	Baudio *baudio = audiomain->audiolist;
 
 #ifdef DEBUG
-	printf("midiChannelPressure()\n");
+	printf("midiChannelPressure(%i)\n", msg->params.channelpress.pressure);
 #endif
-#warning - no channel pressure support yet
-	return(0);
+
 	while (baudio != NULL)
 	{
 		if ((baudio->midichannel == msg->channel)
 			|| (baudio->midichannel == BRISTOL_CHAN_OMNI))
 		{
 			baudio->chanPress.pressure = msg->params.channelpress.pressure;
-			baudio->chanpressure = ((float) baudio->chanPress.pressure) / 127;
+			baudio->chanpressure = ((float) baudio->chanPress.pressure)/127.0f;
 
 			if (baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				printf("midiChannelPressure(%i, %i)\n",
+					msg->channel,
+					msg->params.channelpress.pressure);
+			if (baudio->midiflags & BRISTOL_MIDI_DEBUG2)
 				bristolMidiPrint(msg);
 		}
 
 		baudio = baudio->next;
 	}
 
-	while (voice->next != NULL)
+	while (voice != NULL)
 	{
-		voice->chanpressure = baudio->chanpressure;
+		if ((voice->baudio != NULL)
+			&& ((voice->baudio->midichannel == msg->channel)
+				|| (baudio->midichannel == BRISTOL_CHAN_OMNI)))
+			voice->chanpressure = voice->baudio->chanpressure;
+
 		voice = voice->next;
 	}
 	return(0);
@@ -373,7 +398,7 @@ midiPitchWheel(audioMain *audiomain, bristolMidiMsg *msg)
 
 	while ((baudio = findBristolAudioByChan(baudio, msg->channel)) != NULL)
 	{
-		if (baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+		if (baudio->midiflags & BRISTOL_MIDI_DEBUG2)
 			bristolMidiPrint(msg);
 
 		if (baudio->gtune == 0)
@@ -415,7 +440,11 @@ static int midiSystem(audioMain *audiomain, bristolMidiMsg *msg)
 	/*
 	 * First take a peek to see if this is a "SLab" message.
 	 */
-	if (strncmp((const char *) &msg->params.bristol.SysID, "SLab", 4) == 0)
+	if ((strncmp((const char *) &msg->params.bristol.SysID, "SLab", 4) == 0)
+		|| ((msg->params.bristol.SysID == ((audiomain->SysID >> 24)))
+			&& (msg->params.bristol.L == ((audiomain->SysID >> 16)&0x00ff))
+			&& (msg->params.bristol.a == ((audiomain->SysID >> 8)&0x00ff))
+			&& (msg->params.bristol.b == ((audiomain->SysID & 0x00ff)))))
 	{
 /*		bristolOPParams *params; */
 
@@ -445,6 +474,29 @@ static int midiSystem(audioMain *audiomain, bristolMidiMsg *msg)
 			return(0);
 		}
 
+		/*
+		 * LADI is primarily handled in the MIDI thread as it needs to forward
+		 * the requests to any attached GUI.
+		 */
+		if (msg->params.bristol.operator == BRISTOL_LADI)
+		{
+			switch (msg->params.bristol.controller) {
+				case BRISTOL_LADI_SAVE_REQ:
+					if (audiomain->debuglevel > 1)
+						printf("ladi relooped save request %x/%x\n",
+							msg->params.bristol.valueMSB,
+							msg->params.bristol.valueLSB);
+					return(0);
+				case BRISTOL_LADI_LOAD_REQ:
+					if (audiomain->debuglevel > 1)
+						printf("ladi relooped load request %x/%x\n",
+							msg->params.bristol.valueMSB,
+							msg->params.bristol.valueLSB);
+					return(0);
+			}
+			return(0);
+		}
+
 		/*
 		 * Insert some code to check the BRISTOL_ACTIVE_SENSE here. These are
 		 * sent from the GUI and if they are found then we will check them 
@@ -484,6 +536,14 @@ static int midiSystem(audioMain *audiomain, bristolMidiMsg *msg)
 				msg->params.bristol.controller,
 				adjusted);
 
+		/* These are for type 2 messages, not yet to the engine, only from */
+		if (msg->params.bristol.msgType > 7)
+		{
+			if (baudio->midiflags & BRISTOL_MIDI_DEBUG1)
+				printf("engine does not handle bristol type2 messages yet\n");
+			return(0);
+		}
+
 		if (msg->params.bristol.operator < baudio->soundCount) {
 			/*
 			 * Find out if this is a float val or what? Alternatively, find
@@ -699,7 +759,11 @@ initMidiControllerMap(int index, int *map, float *floatmap)
 	tmpmap[0] = 0.00001;
 	tmpmap[127] = 127.0;
 
-	bristolGetMap("midicontrollermap", &eventNames[index][0], tmpmap, 128, 0);
+	/* Build a keymap, watch out for failed mappings */
+	if (bristolGetMap("midicontrollermap",
+		&eventNames[index][0], tmpmap, 128, 0) <= 0)
+		for (i = 0; i < 128; i++)
+			tmpmap[i] = i;
 
 	sprintf(param, "%sFloat", &eventNames[index][0]);
 	bristolGetMap("midicontrollermap", param, floatmap, 128, 0);
@@ -749,8 +813,10 @@ initMidiRoutines(audioMain *audiomain, midiHandler midiRoutines[])
 		initMidiControllerMap(i, &midiRoutines[i].map[0],
 			&midiRoutines[i].floatmap[0]);
 
-	bristolGetMap("midicontrollermap", "midiNoteMap",
-		&midiRoutines[7].floatmap[0], 128, 0);
+	if (bristolGetMap("midicontrollermap", "midiNoteMap",
+		&midiRoutines[7].floatmap[0], 128, 0) <= 0)
+		for (i = 0; i < 128; i++)
+			midiRoutines[7].floatmap[i] = i;
 
 	for (i = 0; i < 128; i++)
 	{
