@@ -43,7 +43,7 @@ doMNL(bristolVoice *voice, int key, int velocity, int action)
 		return(0);
 
 	if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG1)
-		printf("monoPhonic Note Logic (%i %i)\n", key, action);
+		printf("monophonic note logic (%i %i)\n", key, action);
 
 	if (action == BRISTOL_ALL_NOTES_OFF)
 	{
@@ -404,33 +404,45 @@ rbMidiNoteOff(audioMain *audiomain, bristolMidiMsg *msg)
 			 * Just take it off the newlist and put on the freelist. This was
 			 * damaged for a while as it assumed we were looking at the head
 			 * of the newlist and it was not doubly linked.
+			 *
+			 * I think this causes clicks due to forced close of the envelope.
+			 * Changed the logic from remove from list to KEYOFF
 			 */
 			voice->flags &= ~(BRISTOL_KEYON|BRISTOL_KEYREON);
 
-			v = voice->next;
+			if (voice->baudio->voicecount > 1)
+			{
+				v = voice->next;
 
-			if (voice->next != NULL)
-				voice->next->last = voice->last;
-			else
-				audiomain->newlast = voice->last;
-			if (voice->last != NULL)
-				voice->last->next = voice->next;
-			else
-				audiomain->newlist = voice->next;
+				if (voice->next != NULL)
+					voice->next->last = voice->last;
+				else
+					audiomain->newlast = voice->last;
+				if (voice->last != NULL)
+					voice->last->next = voice->next;
+				else
+					audiomain->newlist = voice->next;
 
-			if ((voice->next = audiomain->freelist) == NULL)
-				audiomain->freelast = voice;
-			else
-				voice->next->last = voice;
-			voice->last = NULL;
-			audiomain->freelist = voice;
+				if ((voice->next = audiomain->freelist) == NULL)
+					audiomain->freelast = voice;
+				else
+					voice->next->last = voice;
+				voice->last = NULL;
+				audiomain->freelist = voice;
 
-			if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG2)
-				printf("mt: off: removed %p/%i from newlist\n",
-					voice, voice->keyid);
+				if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG2)
+					printf("mt: off: removed %p/%i from newlist\n",
+						voice, voice->keyid);
 
-			voice = v;
-			continue;
+				voice = v;
+				continue;
+			} else {
+				voice->flags |=
+					BRISTOL_KEYOFF|BRISTOL_KEYSUSTAIN|BRISTOL_KEYREOFF;
+				if (voice->baudio->midiflags & BRISTOL_MIDI_DEBUG2)
+					printf("mt: off: %p->%p/%i was on newlist\n",
+						voice, voice->next, voice->keyid);
+			}
 		}
 
 		voice = voice->next;
@@ -749,7 +761,29 @@ doMidiNoteOn(audioMain *audiomain, bristolMidiMsg *msg, Baudio *baudio, int key)
 			 * If we only have a single voice available and this is it, use it
 			 */
 			if (baudio->voicecount == 1)
-				break;
+			{
+				voice->flags &= ~(BRISTOL_KEYON|BRISTOL_KEYREON);
+					voice->flags |= BRISTOL_KEYREON;
+
+				voice->keyid = key;
+				voice->offset = offset;
+				voice->key.key = transposedkey;
+				voice->key.velocity = velocity;
+				voice->velocity = mappedvelocity;
+				voice->lastkey = lastkey;
+				voice->dFreq = dFreq;
+				voice->cFreq = cFreq;
+				voice->cFreqmult = cFreqmult;
+				voice->dfreq = dfreq;
+				voice->cfreq = cfreq;
+				voice->cfreqmult = cfreqmult;
+				voice->detune = dTune;
+
+#ifdef BRISTOL_SEMAPHORE
+				sem_post(audiomain->sem_long);
+#endif
+				return(0);
+			}
 
 			if (voice->keyid == msg->params.key.key)
 				break;
@@ -828,6 +862,13 @@ midiNoteOn(audioMain *audiomain, bristolMidiMsg *msg)
 	Baudio *baudio = audiomain->audiolist;
 #else
 
+	if (msg->params.key.velocity == 0)
+	{
+		msg->command = MIDI_NOTE_OFF|(msg->command & MIDI_CHAN_MASK);
+		msg->params.key.velocity = 64;
+		return(midiNoteOff(audiomain, msg));
+	}
+
 	/*
 	 * So, if this came from a jack handle, and we are single open then don't
 	 * dump this in the ringbuffer - call the handler directly
@@ -866,7 +907,11 @@ rbMidiNoteOn(audioMain *audiomain, bristolMidiMsg *msg)
 	 * results
 	 */
 	if (msg->params.key.velocity == 0)
-		return(midiNoteOff(audiomain, msg));
+	{
+		msg->command = MIDI_NOTE_OFF|(msg->command & MIDI_CHAN_MASK);
+		msg->params.key.velocity = 64;
+		return(rbMidiNoteOff(audiomain, msg));
+	}
 
 	/*
 	 * Find an associated baudio structure. We have to go through the
