@@ -325,7 +325,7 @@ midiThread(audioMain *audiomain)
 			device = "bristol";
 		else
 			device = audiomain->mididev;
-		printf("midi sequencer: %s\n", device);
+		printf("midi interface: %s\n", device);
 	} else if (audiomain->mididev != (char *) NULL)
 		device = audiomain->mididev;
 
