@@ -257,6 +257,14 @@ struct bristolAlgos {
 	{NULL, NULL}
 };
 
+void
+newPalette()
+{
+	/*
+	 * This is defined in fatboy headers, here we only have a null call
+	 */
+}
+
 struct bristolEffects {
 	bristolOP * (*initialise)(audioMain *, Baudio *);
 } bristolEffects[BRISTOL_SYNTHCOUNT] = {
