@@ -118,7 +118,7 @@ static int param(bristolOP *operator, bristolOPParams *param,
 #endif
 	switch (index) {
 		case SPEED:
-			param->param[index].float_val = value;
+			param->param[index].float_val = value * value * value;
 			param->param[index].int_val = 532 - value * 512;
 /* printf("speed is %i\n", param->param[index].int_val); */
 			break;
@@ -536,7 +536,7 @@ nSpeed, Speed, inertia, param->param[3].int_val, local->tinc);
 }
 
 static void
-newValvify(register float *busData, register int count, register float valve)
+iSnewValvify(register float *busData, register int count, register float valve)
 {
 	register float div, *busData2 = busData;
 
@@ -566,6 +566,40 @@ newValvify(register float *busData, register int count, register float valve)
 	}
 }
 
+static float lpf = 0; // need to bury in a local structure
+
+static void
+newValvify(register float *busData, register int count, register float valve)
+{
+	register int div, i;
+	register float s;
+
+#ifdef DEBUG
+	printf("newValvify(%f)\n", valve);
+#endif
+
+	if ((div = (int) (valve * 3.0f)) >= 2)
+		return;
+
+	for (i = count; i > 0; i--, busData++)
+	{
+		 switch (div) {
+		 	case 3:
+		 	case 2:
+				return;
+		 	default:
+				s = *busData * -0.00390625f + 8.0f;
+				*busData = (s * s * s * 0.00390625f - 8.0f) * 256.0f;
+				break;
+		 	case 1:
+				s = *busData * 0.00390625f + 8.0f;
+				*busData = (s * s * 0.0625f - 8.0f) * 256.0f;
+				break;
+		}
+		*busData -= (lpf += (*busData - lpf) * 0.0001);
+	}
+}
+
 static void
 buildSineTable(float *table)
 {
