@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 /* This is sampler oscillator code. It is not used by any synth at the moment. */
@@ -203,9 +202,8 @@ convertRhodes(sampleData *sd, char *file, int loc, int layer)
 		printf("Could not stat file\n");
 		close(fd);
 	} else
-		printf("filesize is %i bytes\n", (size_t) sbuf.st_size);
+		printf("filesize is %i bytes\n", (int) sbuf.st_size);
 
-#warning - need to free this memory on exit
 	sd[loc].layer[layer].wave
 		= (float *) bristolmalloc((sbuf.st_size / 2) * sizeof(float));
 
