@@ -25,6 +25,7 @@
 #define SOLINA_OSC2_SQR	0x008
 #define SOLINA_OSC3_SAW	0x010
 #define SOLINA_OSC3_SQR	0x020
+#define SOLINA_OSCGLIDE	0x040
 
 #define MULTI_LFO		0x0100
 
@@ -32,6 +33,7 @@ typedef struct solinaMods {
 	float pwm;
 	float vibrato;
 	float tremelo;
+	float glide;
 	int lowsplit;
 	int highsplit;
 } solinamods;
