@@ -18,6 +18,7 @@
  *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
+#include <stdlib.h>
 #include "bristol.h"
 
 extern audioMain audiomain;
@@ -27,22 +28,62 @@ bristolSound *
 dropBristolOp(int op, bristolOP *palette[])
 {
 	bristolSound *newsound;
+	int i = 5;
 
 	if (palette == NULL)
 		midithreadexit();
+
 	if (palette[op] == NULL)
 	{
 		printf("Null palette entry %i\n", op);
+
+		while (palette[op] == NULL) {
+			sleep(1);
+
+			if (--i == 0)
+			{
+				printf("Null pallet entry: unrecovered\n");
+				exit(0);
+			}
+		}
+
 		if (palette[0] == NULL)
 			printf("Null zero palette entry\n");
 		else
 			printf("%s\n", palette[0]->specs->opname);
-		midithreadexit();
+
+		i = 5;
+
+		while (palette[0] == NULL) {
+			sleep(1);
+
+			if (--i == 0)
+			{
+				printf("Null zero pallet entry: unrecovered\n");
+				exit(0);
+			}
+		}
+
+		printf("recovered\n");
 	}
+
+	i = 5;
+
 	if (palette[op]->specs == NULL)
 	{
 		printf("Null palette specification\n");
-		midithreadexit();
+
+		while (palette[op]->specs == NULL) {
+			sleep(1);
+
+			if (--i == 0)
+			{
+				printf("Null zero pallet entry: unrecovered\n");
+				exit(0);
+			}
+		}
+
+		printf("Null palette specification, recovered\n");
 	}
 
 	/*
