@@ -26,8 +26,11 @@
  * (5 octaves = 62). In short, the lowest drawbar goes 12 notes below the 
  * bottom key, and the highest note goes 3 octaves (36 notes) above, or rather
  *		61 + 12 + 36 = 109 frequencies.
- * We pull back to 91 using "foldback", which is reusing different bus routings
- * on the uppermost and lowermost ranges.
+ * We pull back to 92 using "foldback", which is reusing different bus routings
+ * on the uppermost and lowermost ranges. The original has 24 compartments with
+ * 4 wheels each giving 96 wheels however 4 were 'dummies' with no teeth just
+ * installed for balancing the mechanics. This is characterised in the bristol
+ * tonewheel definition file.
  *
  * We also need to look at introducing "tonewheel damping", ie, when a given
  * wheel is used more than once then its gain does not increment linearly,
@@ -147,9 +150,10 @@ typedef struct Tonewheels {
 	/* There are more, we could bury the wavetables and buffers in here. */
 } tonewheels;
 
-tonewheels gearbox[91];
+tonewheels gearbox[92];
 
-static int bright, samplerate;
+/* Bright should be burried in the tonewheel structure */
+static int bright, btnote, btdelay = 0, samplerate;
 
 #ifdef TONEMATRIX
 struct {
@@ -266,7 +270,7 @@ thesermon(int samplecount, int sineform)
 
 	/*
 	 * We now have 8 waves, which are anything from sines, leading edge sines,
-	 * tris and ramps. We now need to fill all 109 tables with the number of 
+	 * tris and ramps. We now need to fill all 92 tables with the number of 
 	 * samples required for the next buffer SAMPLE_COUNT samples from these
 	 * wave tables. Choice of wave will initially be parameterised, but 
 	 * eventually we should be looking to select the wave based on the octave
@@ -346,15 +350,17 @@ int *percs, register int count, float gn, float damp, float cg, int flags,
 float velocity)
 {
 	register int bus, i, j, index;
-	register float gain, *dest = buf, *source;
+	register float gain = 0, *dest = buf, *source;
+#ifdef NEW_CLICK
+	register float clickg;
+#endif
 
-	gain = 0;
 	cg *= 0.125;
 
 	/*
 	 * We should check the note values and discard any requests outside of 
 	 * our valid range (0 to 60. The reason we need to check this regards the
-	 * toothwheel tables that are sized for 91 teeth.
+	 * toothwheel tables that are sized for 92 teeth.
 	 */
 	while (note < 0)
 		note+=12;
@@ -373,20 +379,49 @@ float velocity)
 	 * work reasonably anyway, due to the staggered busses.
 	 */
 #ifdef NEW_CLICK
+	/*
+	 * We should not do this for REON as the bus delay will introduce another
+	 * unrequested tick. REON for this emulator will not happen often as it
+	 * has short decay and plenty of voices typically.
 	if (flags & (BRISTOL_KEYON|BRISTOL_KEYREON))
+	 */
+	if (flags & BRISTOL_KEYON)
 	{
-printf("note on %f: %i %i\n", velocity, note, bright);
+//printf("note on %f: %i %i\n", velocity, note, bright);
 		drawbars.offset[note] = 0;
 
+//printf("velocity %f = ", velocity);
+//		velocity = velocity * velocity * velocity * velocity;
+		velocity = 1.0f - velocity;
+		velocity = velocity * velocity;
+//printf("%f\n", velocity);
+
+		/*
+		 * If this is the same note then we do note not change the bus delay
+		 * offsets: repetitive playing of the same notes will give the same
+		 * set of transient delays. If we are playing different note sequences
+		 * then this will ensure that any given drawbar bus contact profile
+		 * changes over time.
+		 *
+		 * Without this code then the note busbar delays are always the same
+		 * for every note on the keyboard (well, apart from the effect of
+		 * velocity).
+		 */
+		if ((btnote != note) && (++btdelay > 8))
+			btdelay = 0;
+
 		for (bus = 0; bus < BUS_COUNT; bus++)
 		{
-			drawbars.current[bus][note] = 0;
-			drawbars.tdelay[bus][note] = (int)
-				(drawbars.delay[bright][bus] * (1.0 - velocity));
+			drawbars.current[btdelay][note] = 0;
+			drawbars.tdelay[btdelay][note] = (int)
+				drawbars.delay[bright][bus] * velocity;
+			if (++btdelay >= BUS_COUNT)
+				btdelay = 0;
 		}
 
+		btnote = note;
+
 		/*
-		 */
 		printf("preacher note %i on event: %i %i %i %i %i %i %i %i %i\n", note,
 			drawbars.tdelay[0][note], drawbars.tdelay[1][note],
 			drawbars.tdelay[2][note], drawbars.tdelay[3][note],
@@ -396,13 +431,12 @@ printf("note on %f: %i %i\n", velocity, note, bright);
 		printf("%f: %1.2f %1.2f %1.2f %1.2f %1.2f %1.2f %1.2f %1.2f %1.2f\n",
 			velocity,
 			drawbars.gain[bright][0], drawbars.gain[bright][1],
-			drawbars.gain[bright][2], drawbars.gain[bright][3],
-			drawbars.gain[bright][4], drawbars.gain[bright][5],
+			drawbars.gain[bright][2], drawbars.gain[bright][3], drawbars.gain[bright][4], drawbars.gain[bright][5],
 			drawbars.gain[bright][6], drawbars.gain[bright][7],
 			drawbars.gain[bright][8]);
+		 */
 		/*
-		*/
-		printf("%x, %x, %x, %x, %x, %x, %x, %x, %x\n", 
+		printf("%p, %p, %p, %p, %p, %p, %p, %p, %p\n", 
 		&waves[drawbars.pulse[bright][0]][0],
 		&waves[drawbars.pulse[bright][1]][0],
 		&waves[drawbars.pulse[bright][2]][0],
@@ -418,6 +452,7 @@ printf("note on %f: %i %i\n", velocity, note, bright);
 		drawbars.pulse[bright][4], drawbars.pulse[bright][5],
 		drawbars.pulse[bright][6], drawbars.pulse[bright][7],
 		drawbars.pulse[bright][8]);
+		 */
 	} else
 		drawbars.offset[note] += count;
 #endif
@@ -457,7 +492,7 @@ THE TONEMATRIX IS BROKEN FOR THE NEW BUSDELAYS
 
 			tonegains[index] *= (damp * damping[bright][index]);
 		}
-#else
+#else /* ELSE NOT TONEMATRIX */
 		/*
 		 * This is the unoptimized pre-tonematrix code that is currently 
 		 * compiled with the engine (0.10.2). The optimized code is not yet
@@ -492,7 +527,7 @@ THE TONEMATRIX IS BROKEN FOR THE NEW BUSDELAYS
 
 #ifdef NEW_CLICK
 		/*
-		 * There are a several cases, one where the bus is silent, ie, it
+		 * There are several cases, one where the bus is silent, ie, it
 		 * has not yet made contact, one where the bus is partially silent
 		 * one where it is totally mixed with click, and one where click
 		 * is ending and the normal state of just the bus data.
@@ -519,7 +554,7 @@ THE TONEMATRIX IS BROKEN FOR THE NEW BUSDELAYS
 		}
 		else if ((drawbars.offset[note] + count) < drawbars.tdelay[bus][note])
 		{
-printf("no contact: %i: %f\n", bus, cg);
+//printf("no contact: %i: %f\n", bus, cg);
 			/* 
 			 * Contact not yet made
 			 */
@@ -535,11 +570,11 @@ printf("no contact: %i: %f\n", bus, cg);
 				- drawbars.tdelay[bus][note]];
 			 */
 			float *clickp = &(waves[drawbars.pulse[bright][bus]])
-				[drawbars.offset[note] - drawbars.tdelay[bus][note]];
+				[(int)drawbars.offset[note] - drawbars.tdelay[bus][note]];
 
 			clickg = cg * drawbars.gain[bright][bus];
 
-printf("second half buffer: %i %f\n", bus, clickg);
+//printf("second half buffer: %i %f\n", bus, clickg);
 
 			int halfway = drawbars.tdelay[bus][note] + CLICK_SIZE
 				- drawbars.offset[note];
@@ -556,9 +591,9 @@ printf("second half buffer: %i %f\n", bus, clickg);
 			float *clickp = &(waves[drawbars.pulse[bright][bus]])[0];
 
 			clickg = cg * drawbars.gain[bright][bus];
-printf("first half buffer: %i %f: %i - %i = %i\n", bus, clickg,
-drawbars.tdelay[bus][note], drawbars.offset[note],
-(drawbars.tdelay[bus][note] - drawbars.offset[note]));
+//printf("first half buffer: %i %f: %i - %i = %i\n", bus, clickg,
+//drawbars.tdelay[bus][note], drawbars.offset[note],
+//(drawbars.tdelay[bus][note] - drawbars.offset[note]));
 
 			/* 
 			 * Note started halfway through buffer
@@ -574,10 +609,10 @@ drawbars.tdelay[bus][note], drawbars.offset[note],
 		else
 		{
 			float *clickp = &(waves[drawbars.pulse[bright][bus]])
-				[drawbars.offset[note] - drawbars.tdelay[bus][note]];
+				[(int) drawbars.offset[note] - drawbars.tdelay[bus][note]];
 
 			clickg = cg * drawbars.gain[bright][bus];
-printf("full buffer: %i %f\n", bus, clickg);
+//printf("full buffer: %i %f\n", bus, clickg);
 
 			/*
 			 * Just mix with click
@@ -594,9 +629,9 @@ printf("full buffer: %i %f\n", bus, clickg);
 				*dest++ += *source++ * gain + *clickp++ * clickg;
 			}
 		}
-#endif
+#endif /* NEW_CLICK */
 
-#endif /* TONEMATRIX */
+#endif /* NOT TONEMATRIX */
 
 /*
 printf("gains %i are %f %f %f\n",
@@ -628,7 +663,7 @@ gearbox[index].crosstalk[2].gain);
 #ifdef TONEMATRIX
 				tonematrix[gearbox[index].crosstalk[bright][i].wheel].gain
 					+= gearbox[index].crosstalk[bright][i].gain;
-#else
+#else /* TONEMATRIX */
 				source = tonewheel[gearbox[index].crosstalk[bright][i].wheel];
 				if (percs[bus])
 					dest = pbuf;
@@ -655,7 +690,7 @@ gearbox[index].crosstalk[2].gain);
 					*dest++ += *source++ * gain;
 					*dest++ += *source++ * gain;
 				}
-#endif /* TONEMATRIX */
+#endif /* NOT TONEMATRIX */
 			}
 		}
 
@@ -1611,7 +1646,7 @@ initthesermon(int sc, int sr, int compress)
 	int i;
 	float wavepoints[2][OSC_LIMIT];
 
-/*	printf("initthesermon(%i, %i)\n", sc, sr); */
+	/* printf("initthesermon(%i, %i, %i)\n", sc, sr, compress); */
 
 	samplerate = sr; /* We need this for bus delay timing */
 
@@ -1801,11 +1836,11 @@ drawbars.gain[BRIGHT][8]);
 	{
 		if (wavepoints[NORMAL][i] > 1.0)
 			filltriwave(&wheeltemplates[NORMAL][i][0],
-				WAVE_SIZE, wavepoints[NORMAL][i], 0);
+				WAVE_SIZE, wavepoints[NORMAL][i], compress);
 		else
 			fillsquarewave(&wheeltemplates[0][i][0],
 				WAVE_SIZE, wavepoints[NORMAL][i],
-				wavepoints[NORMAL][i] > 0.55? 1:2);
+				compress); //wavepoints[NORMAL][i] > 0.55? 1:2);
 	}
 
 	for (i = 0; i < OSC_LIMIT; i++)
@@ -1841,7 +1876,7 @@ fillsquarewave(register float *mem, register int count,
 register double reach, int compress)
 {
 	register int i, newcount;
-	register float increment = 0.0;
+	register float increment = 0.0, l;
 
 	/* 
 	 * Change the number of samples we will actually fill with the cosine.
@@ -1855,6 +1890,17 @@ register double reach, int compress)
 	for (;i < count; i++)
 		mem[i] = HAMMOND_WAVE_GAIN;
 
+	if (compress)
+	{
+		for (i = 0;i < count; i++)
+		{
+			//mem[i] = (-mem[i] + 8.0f) * (-mem[i] + 8.0f) * (-mem[i] + 8.0f)
+			//	/ 256.0f - 8.0f;
+			l = mem[i] + 8;
+			mem[i] = l * l * l * 0.00390625f - 8.0f;
+		}
+	}
+
 /*
 	printf("\n%f, %f\n", j, inc);
 	for (i = 0; i < count; i+=8)
@@ -1872,14 +1918,15 @@ filltriwave(register float *mem, register int count,
 register double reach, int compress)
 {
 	register int i, recalc1 = 1, recalc2 = 1;
-	register double j = 0, Count = (double) count, inc = reach, l;
+	float j = 0, inc = reach;
+	float l;
 
 	for (i = 0;i < count; i++)
 	{
 		if ((j > (count * 3 / 4)) && recalc2)
 		{
 			recalc2 = 0;
-			inc = ((float) (count / 4)) / (((float) count) - i);
+			inc = count / 4 / (count - i);
 		} else if ((j > (count / 4)) && recalc1) {
 			recalc1 = 0;
 			/* 
@@ -1887,22 +1934,31 @@ register double reach, int compress)
 			 * of steps required to get the sine back to zero crossing by
 			 * the time i = count / 2, ie, count /4 steps in total.
 			 */
-			inc = ((float) (count / 4)) / (((float) (count / 2)) - i);
+			inc = count / 4 / (count / 2 - i);
 		}
 
 		j += inc;
 
-		if (compress)
-		{
-			l = sin(((double) (2 * M_PI * -j)) / Count);
-			if (l < 0)
-				mem[i] = -16 * sqrt(-l * HAMMOND_WAVE_GAIN);
-			else
-				mem[i] = 16 * sqrt(l * HAMMOND_WAVE_GAIN);
-		} else
-			mem[i] = sin(((double) (2 * M_PI * j)) / Count) * HAMMOND_WAVE_GAIN;
+		mem[i] = sinf((2 * M_PI * j) / count) * HAMMOND_WAVE_GAIN;
 	}
 
+	if (compress)
+	{
+		for (i = 0;i < count; i++)
+		{
+			//mem[i] = (mem[i] + 8.0f) * (mem[i] + 8.0f) * (mem[i] + 8.0f)
+			//	/ 256.0f - 8.0f;
+			l = mem[i] + 8;
+			mem[i] = l * l * l * 0.00390625f - 8.0f;
+		}
+	}
+
+
+//			mem[i] =
+//				(mem[i] * (mem[i] * (mem[i] + 24) + 192) + 512) / 256.0f - 8.0f;
+//			l = mem[i] + 8;
+//			mem[i] = l * l * l * 0.00390635f - 8.0f;
+
 /*
 	printf("\n%f, %f\n", j, inc);
 	for (i = 0; i < count; i+=8)
