@@ -130,7 +130,7 @@
 
 #define BRISTOL_CHAN_OMNI		127 /* Denotes any midi channel. */
 
-#define BRISTOL_VOICECOUNT		32 /* Was 16, now increased for GM-2 24/32 */
+//#define BRISTOL_VOICECOUNT		32 /* Was 16, now increased for GM-2 24/32 */
 #define BRISTOL_MAXVOICECOUNT	128
 #define BRISTOL_SYNTHCOUNT		64
 
@@ -233,9 +233,9 @@
 #define BRISTOL_AUDIOMASK		0xff000000
 #define BRISTOL_ALSA			0x01000000
 #define BRISTOL_OSS				0x02000000
-#define BRISTOL_SLAB			0x04000000 /* should deprecte this */
+#define BRISTOL_PULSE			0x04000000
 #define BRISTOL_JACK			0x08000000
-#define BRISTOL_PULSE			0x10000000 /* Threaded */
+#define BRISTOL_PULSE_T			0x10000000 /* Threaded */
 #define BRISTOL_PULSE_S			0x20000000 /* Simple - lots of latency */
 #define BRISTOL_DUMMY			0x40000000
 /* This appears to collide */
@@ -354,6 +354,7 @@ typedef struct BristolParam {
 #define BRISTOL_KEYREON		0x0010
 #define BRISTOL_KEYOFFING	0x0020
 #define BRISTOL_KEYSUSTAIN	0x0040
+#define BRISTOL_KEYREOFF	0x0080
 /*
  * There are Korg Mono/Poly specifics for VCO assignment.
  */
