@@ -38,7 +38,10 @@ extern void brightonShiftKeyInput(brightonWindow *, int, int, int);
 extern void brightonControlShiftKeyInput(brightonWindow *, int, int, int);
 extern void printColorCacheStats(brightonWindow *);
 
-extern int brightonMenu();
+/*
+ * TOOK THIS OUT BY POPULAR DEMAND
+ */
+//extern int brightonMenu();
 
 int
 brightonKeyPress(brightonWindow *bwin, brightonEvent *event)
@@ -156,10 +159,13 @@ brightonButtonPress(brightonWindow *bwin, brightonEvent *event)
 	if (bwin->flags & BRIGHTON_DEBUG)
 		printf("brightonButtonPress(%i)\n", event->key);
 
+	/*
+	 * TOOK THIS OUT BY POPULAR DEMAND
 	if (event->key == BRIGHTON_BUTTON3) {
 			brightonMenu(bwin, event->x, event->y, 100, 200);
 		return(0);
 	}
+	 */
 
 	/*
 	 * We need to determine which device is under the selection, and force
@@ -195,10 +201,13 @@ brightonButtonRelease(brightonWindow *bwin, brightonEvent *event)
 
 	event->command = BRIGHTON_BUTTONRELEASE;
 
+	/*
+	 * TOOK THIS OUT BY POPULAR DEMAND
 	if (event->key == BRIGHTON_BUTTON3) {
 			brightonMenu(bwin, event->x, event->y, 100, 200);
 		return(0);
 	}
+	 */
 
 	/*if (bwin->activepanel && bwin->activepanel->configure) */
 	if ((bwin->flags & BRIGHTON_DEV_ACTIVE) && (bwin->activepanel != 0))
@@ -643,7 +652,7 @@ int
 brightonClientMessage(brightonWindow *bwin, brightonEvent *event)
 {
 	if (bwin->flags & BRIGHTON_DEBUG)
-		printf("brightonClientRequest()\n");
+		printf("brightonClientMessage()\n");
 	return(0);
 }
 
