@@ -666,6 +666,8 @@ statFunction(int op, char *operation)
 }
 #endif
 
+static int lock = 0;
+
 int
 brightonDoFinalRender(brightonWindow *bwin,
 register int x, register int y, register int width, register int height)
@@ -677,23 +679,33 @@ register int x, register int y, register int width, register int height)
 	register int *shadow;
 	register int *top;
 	register int *menu;
+	int count = 40;
 
 #ifdef STATS2
 	statFunction(0, "Brighton");
 #endif
 
+	while (lock)
+	{
+		usleep(25000);
+		if (--count == 0)
+			lock = 0;
+	}
+
+	lock = 1;
+
 	if (bwin == NULL)
-		return(0);
+		return(lock = 0);
 
 	if (bwin->canvas)
 		src = bwin->canvas->pixels;
 	else	
-		return(0);
+		return(lock = 0);
 
 	if (bwin->render)
 		dest = bwin->render->pixels;
 	else 
-		return(0);
+		return(lock = 0);
 
 	device = bwin->dlayer->pixels;
 	shadow = bwin->slayer->pixels;
@@ -701,7 +713,7 @@ register int x, register int y, register int width, register int height)
 	menu = bwin->mlayer->pixels;
 
 	if ((width < 0) || (height < 0))
-		return(0);
+		return(lock = 0);
 
 	aa = bwin->display->flags & (BRIGHTON_ANTIALIAS_1 | BRIGHTON_ANTIALIAS_2);
 
@@ -812,7 +824,7 @@ register int x, register int y, register int width, register int height)
 #ifdef STATS2
 	statFunction(1, "Library");
 #endif
-	return(0);
+	return(lock = 0);
 }
 
 int
