@@ -40,9 +40,13 @@ BOpenWindow(brightonDisplay *display, brightonWindow *bwin, char *programme)
 
 	bd->x = bwin->x; bd->y = bwin->y;
 
+	/*
+	printf("libbrightonB11: %p %i, %i, %i, %i\n",
+		bd->display, bwin->x, bwin->y, bwin->width, bwin->height);
+	 */
+
 	bwin->win = XCreateSimpleWindow(bd->display,
-		RootWindow(bd->display,
-		bd->screen_num),
+		RootWindow(bd->display, bd->screen_num),
 		bwin->x, bwin->y,
 		bwin->width, bwin->height, bd->border,
 		WhitePixel(bd->display, bd->screen_num),
