@@ -89,8 +89,12 @@ bristolAudioOpen(char *device, int rate, int count, int flags)
 	audioDev.fragBuf = 0;
 	audioDev.OSegmentSize = audioDev.fragSize;
 #if (BRISTOL_HAS_ALSA == 1)
-	if ((flags & BRISTOL_OSS) == 0)
-		audioDev.siflags |= AUDIO_ALSA;
+	if (flags & BRISTOL_ALSA)
+		audioDev.siflags = AUDIO_ALSA;
+#endif
+#ifdef BRISTOL_PA
+	if (flags & BRISTOL_PULSE_S)
+		audioDev.siflags = AUDIO_PULSE;
 #endif
 	audioDev.cflags |= SLAB_SUBFRAGMENT;
 	audioDev.cflags |= SLAB_AUDIODBG;
@@ -103,7 +107,7 @@ bristolAudioOpen(char *device, int rate, int count, int flags)
 	return(audioDev.fragSize);
 #endif
 
-	audioDev.flags = 0x0d;
+	audioDev.flags = SLAB_FULL_DUPLEX;
 
 	if (flags & BRISTOL_DUMMY)
 		audioDev.flags |= AUDIO_DUMMY;
