@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -48,13 +47,14 @@ bristolmalloc0(size)
 #ifdef DEBUG
 	printf("bristolmalloc0: %x, %i\n", mem, size);
 #endif
+
 	bzero(mem, size);
 
 	return(mem);
 }
 
 void
-bristolfree(char *mem)
+bristolfree(void *mem)
 {
 #ifdef DEBUG
 	printf("bristolfree: %x\n", mem);
@@ -62,6 +62,10 @@ bristolfree(char *mem)
 
 	if (mem != NULL)
 		free(mem);
+#ifdef DEBUG
+	else
+		printf("attempt to free (null)\n");
+#endif
 }
 
 void
@@ -71,6 +75,9 @@ bristolbzero(char *mem, int count)
 	printf("bristolzero: %x\n", mem);
 #endif
 
+	if (mem == NULL)
+		return;
+
 	bzero(mem, count);
 }
 
