@@ -96,12 +96,16 @@ int devID;
 	 * Set the fragments.
 	 * In this order set bits, channels, speed.
 	 */
+#ifdef BRISTOL_PA
+	if (audioDev->siflags & AUDIO_PULSE)
+		return(0);
+#endif
 #if (BRISTOL_HAS_ALSA == 1)
 	/*
 	 * ALSA is one of the secondary intrusive flags. If this is set we have
 	 * already configured what we want from the open request on the device.
 	 */
-	if ((audioDev->flags & AUDIO_ALSA) != 0)
+	if (audioDev->siflags & AUDIO_ALSA)
 		return(0);
 #endif
 
@@ -125,8 +129,12 @@ duplexDev *audioDev;
 	if (audioDev->flags & AUDIO_DUMMY)
 		return(0);
 
+#ifdef BRISTOL_PA
+	if (audioDev->siflags & AUDIO_PULSE)
+		return(0);
+#endif
 #if (BRISTOL_HAS_ALSA == 1)
-	if (audioDev->flags & AUDIO_ALSA)
+	if (audioDev->siflags & AUDIO_ALSA)
 	{
 		alsaDevAudioStart(audioDev);
 		return(0);
@@ -162,11 +170,15 @@ duplexDev *audioDev;
 		printf("setAudioStop2(%i)\n", devID);
 #endif
 
-	if (audioDev->flags & AUDIO_DUMMY)
+	if (audioDev->siflags & AUDIO_DUMMY)
 		return(0);
 
+#ifdef BRISTOL_PA
+	if (audioDev->siflags & AUDIO_PULSE)
+		return(0);
+#endif
 #if (BRISTOL_HAS_ALSA == 1)
-	if (audioDev->flags & AUDIO_ALSA)
+	if (audioDev->siflags & AUDIO_ALSA)
 	{
 #ifdef IOCTL_DBG
 		/*
@@ -222,8 +234,16 @@ audioClose(duplexDev *audioDev)
 		return(0);
 	}
 
+#ifdef BRISTOL_PA
+	if (audioDev->siflags & AUDIO_PULSE)
+	{
+		pulseDevClose(audioDev);
+		return(0);
+	}
+#endif
+
 #if (BRISTOL_HAS_ALSA == 1)
-	if (audioDev->flags & AUDIO_ALSA)
+	if (audioDev->siflags & AUDIO_ALSA)
 	{
 		alsaDevClose(audioDev);
 		return(0);
@@ -276,8 +296,12 @@ audioOpen(duplexDev *audioDev, int device, int flags)
 		return(10);
 	}
 
+#ifdef BRISTOL_PA
+	if (audioDev->siflags & AUDIO_PULSE)
+		return(pulseDevOpen(audioDev, device, flags, audioDev->fragSize));
+#endif
 #if (BRISTOL_HAS_ALSA == 1)
-	if ((audioDev->flags & AUDIO_ALSA) && (audioDev->devName[0] != '/'))
+	if ((audioDev->siflags & AUDIO_ALSA) && (audioDev->devName[0] != '/'))
 		return(alsaDevOpen(audioDev, device, flags, audioDev->fragSize));
 #endif
 	/*
@@ -316,7 +340,6 @@ audioOpen(duplexDev *audioDev, int device, int flags)
 #endif
 	}
 
-#ifdef AUDIO_API
 	/*
 	 * We will eventually allow configurable buffer sizes. At the moment we
 	 * will take the default value for the main output device, and
@@ -325,10 +348,18 @@ audioOpen(duplexDev *audioDev, int device, int flags)
 	if (audioDev->fragSize == 0)
 		audioDev->fragSize = 1024;
 	audioDev->flags = flags;
+
+	bristolfree(audioDev->fragBuf);
+
+	audioDev->fragBuf = (char *) bristolmalloc(audioDev->fragSize);
+
 	initAudioDevice2(audioDev, device, audioDev->fragSize);
-#else
-	initAudioDevice(device);
-#endif
+
+	/*
+	audioDev->flags |= SLAB_AUDIODBG2;
+	audioDev->cflags |= SLAB_AUDIODBG;
+	*/
+
 	return(audioDev->fd);
 }
 
