@@ -1,12 +1,12 @@
 
 /*
  *  Diverse SLab audio routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -47,6 +46,8 @@
 #if (BRISTOL_HAS_ALSA  == 1)
 #include "slabalsadev.h"
 
+static struct adev alsaDev[MAX_DEVICES + 1];
+
 int
 checkAudioALSAcaps(audioDev, devID, fd)
 duplexDev *audioDev;
@@ -337,15 +338,14 @@ closeALSAmixer(audioDev)
 duplexDev *audioDev;
 {
 	if (audioDev->cflags & SLAB_AUDIODBG)
-		printf("closeALSAmixer(): %08x\n", (int) alsaDev[audioDev->devID].mh);
+		printf("closeALSAmixer(): %p\n", alsaDev[audioDev->devID].mh);
 
 	if (alsaDev[audioDev->devID].mh != (snd_mixer_t *) NULL)
 	{
 		int err;
 
 		if (audioDev->cflags & SLAB_AUDIODBG)
-			printf("real closeALSAmixer(): %08x\n",
-				(int) alsaDev[audioDev->devID].mh);
+			printf("real closeALSAmixer(): %p\n", alsaDev[audioDev->devID].mh);
 
 		if ((err = snd_mixer_close((void *) alsaDev[audioDev->devID].mh)) < 0)
 		{
