@@ -149,8 +149,12 @@ printf("TCP port: %i\n", service->s_port);
 	 * Attempt a connection on the known socket.
 	 */
 	if (connect(socket_descriptor, (struct sockaddr *) &connect_socket_addr,
-			sizeof(connect_socket_addr)) == -1) {
-		perror("connect failed");
+			sizeof(connect_socket_addr)) == -1)
+	{
+		char errtext[1024];
+
+		sprintf(errtext, "connect failed on %i", port);
+		perror(errtext);
 		(void) close(socket_descriptor);
 		return(-2);
 	}
