@@ -29,9 +29,6 @@
  * All events will be converted into a bristol native message format for
  * independency from the driver.
  */
-
-/*#define DEBUG */
-
 #include <unistd.h>
 #include <strings.h>
 
@@ -85,6 +82,7 @@ void *param)
 
 	if (bmidi.flags & BRISTOL_BMIDI_DEBUG)
 		printf("bristolMidiOpen(%s, %x)\n", dev, flags);
+printf("bristolMidiOpen(%s, %x)\n", dev, flags);
 
 	if (dev == NULL)
 		dev = devname;
@@ -144,6 +142,7 @@ void *param)
 
 		if (bmidi.flags & BRISTOL_BMIDI_DEBUG)
 			printf("reusing connection %x\n", bmidi.dev[devnum].flags);
+printf("reusing connection %x\n", bmidi.dev[devnum].flags);
 
 		return(handle);
 	}
@@ -154,6 +153,8 @@ void *param)
 	if ((devnum = bristolMidiFindDev(NULL)) < 0)
 		return(devnum);
 
+	bmidi.dev[devnum].state = BRISTOL_MIDI_OK;
+
 	/*
 	 * We have early returns here and we should consider cleaning up. The thing
 	 * is that if this call fails then typically the engine will exit. Future
@@ -163,23 +164,39 @@ void *param)
 		case BRISTOL_CONN_TCP:
 			if (handle != bristolMidiTCPOpen(dev, flags,
 				chan, msgs, callback, param, devnum, handle))
+			{
+				bmidi.dev[devnum].state = -1;
+				bmidi.handle[handle].state = -1;
 				return(BRISTOL_MIDI_DRIVER);
+			}
 			bmidi.handle[handle].channel = -1;
 			break;
 		case BRISTOL_CONN_MIDI:
 			if (handle != bristolMidiALSAOpen(dev, flags,
 					chan, msgs, callback, param, devnum, handle))
+			{
+				bmidi.dev[devnum].state = -1;
+				bmidi.handle[handle].state = -1;
 				return(BRISTOL_MIDI_DRIVER);
+			}
 			break;
 		case BRISTOL_CONN_OSSMIDI:
 			if (handle != bristolMidiOSSOpen(dev, flags,
 				chan, msgs, callback, param, devnum, handle))
+			{
+				bmidi.dev[devnum].state = -1;
+				bmidi.handle[handle].state = -1;
 				return(BRISTOL_MIDI_DRIVER);
+			}
 			break;
 		case BRISTOL_CONN_SEQ:
 			if (handle != bristolMidiSeqOpen(dev, flags,
 				chan, msgs, callback, param, devnum, handle))
+			{
+				bmidi.dev[devnum].state = -1;
+				bmidi.handle[handle].state = -1;
 				return(BRISTOL_MIDI_DRIVER);
+			}
 			break;
 		case BRISTOL_CONN_JACK:
 #ifdef _BRISTOL_JACK_MIDI
@@ -196,6 +213,7 @@ void *param)
 		case BRISTOL_CONN_UNIX:
 		default:
 			printf("conn type %x not supported\n", flags & BRISTOL_CONNMASK);
+			bmidi.dev[devnum].state = -1;
 			return(BRISTOL_MIDI_DRIVER);
 			break;
 	}
@@ -211,7 +229,8 @@ void *param)
 	bmidi.handle[handle].callback = callback;
 	bmidi.handle[handle].param = param;
 
-/*printf("returning handle %i, flags %x\n", handle, bmidi.dev[devnum].flags); */
+printf("returning handle %i, flags %x, fd %i\n", handle, bmidi.dev[devnum].flags, bmidi.dev[devnum].fd);
+
 	return(handle);
 }
 
@@ -248,7 +267,7 @@ bristolMidiOption(int handle, int option, int value)
 						bmidi.dev[bmidi.handle[i].dev].flags
 							|= _BRISTOL_MIDI_DEBUG;
 			}
-			if (value > 5)
+			if (value >= 5)
 				bmidi.flags |= BRISTOL_BMIDI_DEBUG;
 			break;
 		}
@@ -401,8 +420,6 @@ bristolMidiRead(int handle, bristolMidiMsg *msg)
 {
 	int c = 50;
 
-#ifdef DEBUG
-#endif
 	if (bmidi.flags & BRISTOL_BMIDI_DEBUG)
 		printf("bristolMidiRead(%i): %i/%i\n", handle,
 			bmidi.handle[handle].dev, bmidi.dev[bmidi.handle[handle].dev].fd);
@@ -506,7 +523,7 @@ bristolMidiTerminate()
 		close(bmidi.dev[0].fd);
 		bmidi.dev[0].fd = -1;
 
-		snprintf(filename, 128, "/tmp/bristol.%s", devname);
+		snprintf(filename, 128, "/tmp/br.%s", devname);
 
 		unlink(filename);
 	}
@@ -800,6 +817,8 @@ bristolMidiSendKeyMsg(int handle, int channel, int operator, int key, int volume
 	return(0);
 }
 
+static int velocity = 0;
+
 int
 bristolMidiSendMsg(int handle, int channel, int operator, int controller,
 	int value)
@@ -831,10 +850,18 @@ bristolMidiSendMsg(int handle, int channel, int operator, int controller,
 		bristolPitchEvent(bmidi.handle[handle].dev, operator, channel, value);
 		return(0);
 	}
+
 	if ((operator == BRISTOL_EVENT_KEYON) || (operator == BRISTOL_EVENT_KEYOFF))
 	{
+		if ((bmidi.flags & BRISTOL_BMIDI_DEBUG) && (++velocity > 127))
+		{
+			velocity = 0;
+			printf("velocity %i\n", velocity);
+		} else
+			velocity = 120;
+
 		return(bristolKeyEvent(bmidi.handle[handle].dev, operator,
-			channel, value & BRISTOL_PARAMMASK, 120));
+			channel, value & BRISTOL_PARAMMASK, velocity));
 	}
 	/*
 	 * We are going to send this through to the control port as a basic format
