@@ -19,17 +19,13 @@
  *
  */
 
-/*#define DEBUG */
-
 #include <unistd.h>
 #include <stdio.h>
 
 int
 bristolPhysWrite(int fd, unsigned char *message, int size)
 {
-#ifdef DEBUG
-	printf("bristolPhysWrite(%i, %i): %x\n", fd, size, message[0]);
-#endif
+	//printf("bristolPhysWrite(%i, %i): %x\n", fd, size, message[0]);
 
 	if (write(fd, message, size) != size)
 	{
