@@ -797,6 +797,9 @@ bristolOpenStdio(int mode)
 			if (lthread != 0)
 				pthread_cancel(lthread);
 			return(0);
+		case BRISTOL_LOG_DISYNTHEGRATE:
+			sprintf(procname, "%s", "disynthegrate");
+			break;
 		case BRISTOL_LOG_BRISTOL:
 			sprintf(procname, "%s", "bristol");
 			break;
