@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol midi routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -59,7 +58,7 @@ midiCheck()
 	/*
 	 * This should go into select() over any opened devices.
 	 */
-	while (!(bmidi.flags & BRISTOL_MIDI_TERMINATE))
+	while (~bmidi.flags & BRISTOL_MIDI_TERMINATE)
 	{
 		FD_ZERO(&Input_fds);
 		count = 0, max = 0;
@@ -83,9 +82,9 @@ midiCheck()
 		}
 
 		/*
-		 * We could wait forever, but use 5 seconds for now.
+		 * We could wait forever, but use 1 second for now.
 		 */
-		waittime.tv_sec = 5;
+		waittime.tv_sec = 1;
 		waittime.tv_usec = 0;
 
 		if (select(max + 1, &Input_fds, NULL, NULL, &waittime) > 0)
