@@ -1,12 +1,12 @@
 
 /*
  *  Diverse Bristol midi routines.
- *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2009
+ *  Copyright (c) by Nick Copeland <nickycopeland@hotmail.com> 1996,2010
  *
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -15,8 +15,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -33,7 +32,7 @@
 extern bristolMidiMain bmidi;
 
 /* We should put this into a structure */
-static int NonOrRegistered, NonOrRegisteredValue;
+static int NonOrRegistered = 0, NonOrRegisteredValue = 0;
 
 void
 bristolMidiPrintGM2(bristolMidiMsg *msg)
@@ -44,12 +43,41 @@ bristolMidiPrintGM2(bristolMidiMsg *msg)
 		msg->GM2.coarse, msg->GM2.fine, msg->GM2.intvalue, msg->GM2.value);
 }
 
+void
+bristolMsgPrint(bristolMsg *msg)
+{
+	printf("ID  0x%x%x%x%x\n", msg->SysID, msg->L, msg->a, msg->b);
+	printf("    msgLen  %i\n", msg->msgLen);
+	printf("    msgType %i\n", msg->msgType);
+	printf("    channel %i\n", msg->channel);
+	printf("    from    %i\n", msg->from);
+	printf("    op      %i\n", msg->operator);
+	printf("    cont    %i\n", msg->controller);
+	printf("    MSB     %i\n", msg->valueMSB);
+	printf("    LSB     %i\n", msg->valueLSB);
+	printf("    value   %i/%x\n",
+		msg->valueLSB + (msg->valueMSB<<7),
+		msg->valueLSB + (msg->valueMSB<<7));
+}
+
 void
 bristolMidiPrint(bristolMidiMsg *msg)
 {
 	int command = ((msg->command & MIDI_COMMAND_MASK) & ~MIDI_STATUS_MASK) >> 4;
 
 	switch (msg->command & MIDI_COMMAND_MASK) {
+		case MIDI_SYSTEM:
+			printf("system");
+			if ((msg->params.bristol.SysID == ((bmidi.SysID >> 24) & 0x0ff))
+				&& (msg->params.bristol.L == ((bmidi.SysID >> 16) & 0x0ff))
+				&& (msg->params.bristol.a == ((bmidi.SysID >> 8) & 0x0ff))
+				&& (msg->params.bristol.b == (bmidi.SysID & 0x0ff)))
+			{
+				printf(" bristol (%i)\n", msg->sequence);
+				bristolMsgPrint(&msg->params.bristol);
+			} else
+				printf("\n");
+			break;
 		case MIDI_NOTE_ON:
 			printf("%s (%i) ch %i: %i, velocity %i\n", eventNames[command],
 				msg->sequence,
@@ -121,7 +149,7 @@ bristolMidiToGM2(int GM2values[128], int midimap[128], u_char valuemap[128][128]
 		/*
 		 * This may be counter productive?
 		 */
-		msg->GM2.c_id = 0;
+		msg->GM2.c_id = -1;
 		msg->GM2.value = 0;
 		return;
 	}
@@ -270,6 +298,8 @@ bristolMidiToGM2(int GM2values[128], int midimap[128], u_char valuemap[128][128]
 	 */
 }
 
+char databytes[1024];
+
 static void
 buildOneMsg(unsigned char p1, unsigned char p2, int dev, bristolMidiMsg *msg)
 {
@@ -293,9 +323,22 @@ buildOneMsg(unsigned char p1, unsigned char p2, int dev, bristolMidiMsg *msg)
 	{
 		msg->params.key.key = p1;
 		msg->params.key.velocity = p2;
+		if (bmidi.dev[dev].flags & BRISTOL_CONN_JACK)
+			msg->params.key.flags = BRISTOL_KF_JACK;
+		else if (bmidi.dev[dev].flags & BRISTOL_CONN_TCP)
+			msg->params.key.flags = BRISTOL_KF_TCP;
+		else
+			msg->params.key.flags = BRISTOL_KF_RAW;
 	}
 
 	switch (msg->command) {
+		case MIDI_SYSTEM:
+			if (msg->params.bristol.msgType >= 8)
+			{
+//				printf("T2 data: %s\n", databytes);
+				msg->params.bristolt2.data = databytes;
+			}
+			break;
 		case MIDI_NOTE_OFF:
 		case MIDI_NOTE_ON:
 		case MIDI_POLY_PRESS:
@@ -328,7 +371,7 @@ parseCommand(unsigned char comm, int dev)
 	 */
 	switch (bmidi.dev[dev].lastcommand) {
 		case MIDI_SYSTEM:
-			if (comm == 0xf7) 
+			if (comm == MIDI_EOS) 
 			{
 				/*
 				if (bmidi.dev[dev].sysex.count != sizeof(bristolMsg))
@@ -337,9 +380,10 @@ parseCommand(unsigned char comm, int dev)
 					printf("Was right length message: %x\n",
 						bmidi.dev[dev].sysex.count);
 				*/
+				bmidi.dev[dev].sysex.count = 0;
 				bmidi.dev[dev].lastcommand = 0;
 			}
-			if (comm == 0xf8) 
+			if (comm == MIDI_SYSEX) 
 			{
 				/*printf("SYSEX checks\n"); */
 				bmidi.dev[dev].sysex.count = 0;
@@ -371,12 +415,8 @@ bristolMidiRawToMsg(unsigned char *buff, int count, int index, int dev,
 {
 	int parsed = 0;
 
-#ifdef DEBUG
-	printf("bristolMidiRawToMsg(%x, %i, %i, %i) [%x]\n",
-		buff, count, index, dev, buff[index]);
-#endif
-
 	msg->command = -1;
+	msg->offset = 0;
 
 	/*
 	 * Attempt to parse a raw message buffer. If we can resolve a complete
@@ -385,6 +425,11 @@ bristolMidiRawToMsg(unsigned char *buff, int count, int index, int dev,
 	if (count <= 0)
 		return(0);
 
+#ifdef DEBUG
+	printf("bristolMidiRawToMsg(%x, %i, %i, %i) [%x]\n",
+		(size_t) buff, count, index, dev, buff[index]);
+#endif
+
 	/*
 	 * Although we know that we have buffered data, we do not know if we are
 	 * being given complete messages by the raw interface - it could be byte by
@@ -393,6 +438,7 @@ bristolMidiRawToMsg(unsigned char *buff, int count, int index, int dev,
 	 *
 	 * Check out our current command in operation on this device:
 	 */
+	bmidi.dev[dev].sysex.count = 0;
 	while (parsed < count)
 	{
 		/*
@@ -401,9 +447,10 @@ bristolMidiRawToMsg(unsigned char *buff, int count, int index, int dev,
 		if ((bmidi.dev[dev].lastcommand != MIDI_SYSTEM) &&
 			(buff[index] & MIDI_STATUS_MASK))
 		 */
-		if (buff[index] & MIDI_STATUS_MASK)
-			parseCommand(buff[index], dev);
-		else {
+		if (buff[index] & MIDI_STATUS_MASK) {
+			parseCommand(buff[index++], dev);
+			return(1);
+		} else {
 			switch (bmidi.dev[dev].lastcommand)
 			{
 				/*
@@ -450,7 +497,7 @@ bristolMidiRawToMsg(unsigned char *buff, int count, int index, int dev,
 				case MIDI_SYSTEM:
 					/*
 					 * Sysex management requires we read bytes until we get
-					 * a status byte, and it should minimally be bocking on 
+					 * a status byte, and it should minimally be blocking on 
 					 * this device. Assume, since we have been sent this, that
 					 * it is going to be a bristolMidiMsg, and look for the 
 					 * first few bytes. If it is SLab we are OK, otherwise we
@@ -461,65 +508,121 @@ bristolMidiRawToMsg(unsigned char *buff, int count, int index, int dev,
 					 * it depending on which byte we have. Could do with some
 					 * error handling!
 					 */
-					if (buff[index] == MIDI_EOS)
+					if (bmidi.dev[dev].sysex.count < 12)
+						((char *) &msg->params.bristol)
+							[bmidi.dev[dev].sysex.count] = buff[index];
+						bmidi.dev[dev].sysex.count++;
+
+					if (bmidi.dev[dev].sysex.count == 4)
 					{
 						/*
-						 * End of SYSEX, see what the message actually looks
-						 * like.
+						 * If this is not a SLab message, then set the
+						 * current state to unknown.
 						 */
-						/*printf("EOS\n"); */
-					} else {
-						((char *) &msg->params.bristol)[
-							bmidi.dev[dev].sysex.count++] = buff[index];
+						if ((msg->params.bristol.SysID
+							!= ((bmidi.SysID >> 24) & 0x07f))
+							|| (msg->params.bristol.L
+								!= ((bmidi.SysID >> 16) & 0x07f))
+							|| (msg->params.bristol.a
+								!= ((bmidi.SysID >> 8) & 0x07f))
+							|| (msg->params.bristol.b
+								!= (bmidi.SysID & 0x07f)))
+						{
+							int rv = bmidi.dev[dev].sysex.count;
 
-						if (bmidi.dev[dev].sysex.count == 5)
-						{
-							/*
-							 * If this is not a SLab message, then set the
-							 * current state to unknown.
-							 */
-							if (strncmp(((char *) &msg->params.bristol), "SLab", 4) != 0)
-							{
-								/*printf("unknown SYSEX type\n"); */
-								bmidi.dev[dev].lastcommand = 0;
-							}
-							/*else */
-							/*	printf("SLab SYSEX type\n"); */
+							printf("unrecognised SYSEX ID %x %x %x %x (%i)\n",
+								msg->params.bristol.SysID,
+								msg->params.bristol.L,
+								msg->params.bristol.a,
+								msg->params.bristol.b,
+								index
+							);
+
+							bmidi.dev[dev].lastcommand = 0;
+							bmidi.dev[dev].sysex.count = 0;
+							return(rv);
 						}
-						if (bmidi.dev[dev].sysex.count == sizeof(bristolMsg))
+							//else printf("SLab SYSEX type\n");
+					}
+
+					if (bmidi.dev[dev].sysex.count == sizeof(bristolMsg))
+					{
+						/* Might be type 2 messages */
+						if (msg->params.bristol.msgType > 7)
 						{
-							if (bmidi.dev[dev].sysex.count
-								== msg->params.bristol.msgLen)
-							{
-								/*printf("Received a SLab SYSEX message\n"); */
-								buildOneMsg(0xff, 0xff, dev, msg);
-								bmidi.dev[dev].lastcommand = 0;
-							} else {
-								/*printf("unknown SYSEX message\n"); */
-								bmidi.dev[dev].lastcommand = 0;
-							}
+							//printf("Received a type 2 message\n");
+							if ((index+=1) >= BRISTOL_MIDI_BUFSIZE)
+								index = 0;
+							parsed++;
+							continue;
+						}
+
+						if (bmidi.dev[dev].sysex.count
+							== msg->params.bristol.msgLen)
+						{
+							// printf("Received a SLab SYSEX message\n");
+							buildOneMsg(0xff, 0xff, dev, msg);
+							bmidi.dev[dev].lastcommand = 0;
+							return(msg->params.bristol.msgLen);
+						} else {
+							int rv = bmidi.dev[dev].sysex.count;
+							// printf("unknown SYSEX message\n");
+							bmidi.dev[dev].lastcommand = 0;
+							bmidi.dev[dev].sysex.count = 0;
+							return(rv);
+						}
+					}
+
+					if (bmidi.dev[dev].sysex.count >= sizeof(bristolMsg))
+					{
+						if ((msg->params.bristol.msgLen >= 1023)
+							|| (msg->params.bristol.msgType < 8))
+						{
+							int rv = bmidi.dev[dev].sysex.count;
+							printf("bad SLab SYSEX message length\n");
+							bmidi.dev[dev].lastcommand = 0;
+							bmidi.dev[dev].sysex.count = 0;
+							return(rv);
+						}
+
+						databytes[bmidi.dev[dev].sysex.count - 1
+							- sizeof(bristolMsg)] = buff[index];
+
+						//printf("inserted %x, %s\n", buff[index], databytes);
+
+						if (bmidi.dev[dev].sysex.count
+							>= msg->params.bristol.msgLen)
+						{
+							/* This is for strings but works generally */
+							databytes[bmidi.dev[dev].sysex.count
+								- sizeof(bristolMsg)] = '\0';
+							buildOneMsg(0xff, 0xff, dev, msg);
+							bmidi.dev[dev].lastcommand = 0;
+							return(msg->params.bristol.msgLen);
 						}
 					}
 					break;
 				default:
 					/*
 					 * Looking for a recognised command:
-					 */
 					if (buff[index] & MIDI_STATUS_MASK)
 						parseCommand(buff[index], dev);
-					break;
+					 */
+					index++;
+
+					return(1);
 			}
 		}
 
 		/*
 		 * Look after our indices
 		 */
-		if ((index+=1) > BRISTOL_MIDI_BUFSIZE)
+		if ((index+=1) >= BRISTOL_MIDI_BUFSIZE)
 			index = 0;
 
 		parsed++;
 	}
 
-	return(parsed);
+	return(0);
 }
 
