@@ -19,7 +19,7 @@
  *
  */
 
-/*#define DEBUG */
+//#define DEBUG
 
 #include "bristol.h"
 #include "bristolmidi.h"
@@ -52,7 +52,12 @@ bristolMidiFindDev(char *name)
 			if (name != (char *) NULL)
 			{
 				if (strcmp(name, bmidi.dev[i].name) == 0)
+				{
+#ifdef DEBUG
+					printf("found dev %s\n", name);
+#endif
 					return(i);
+				}
 			}
 		}
 	}
