@@ -600,7 +600,8 @@ translate_event(snd_seq_event_t *ev, bristolMidiMsg *msg, int dev)
 
 		case SND_SEQ_EVENT_SENSING:
 #ifdef DEBUG
-			printf("\n");
+		if (bmidi.dev[dev].flags & _BRISTOL_MIDI_DEBUG)
+			printf("bristol does not support active sensing\n");
 #endif
 			break;
 
